<?php
/**
 * Установка модуля
 *
 * @package    DIAFAN.CMS
 * @author     diafan.ru
 * @version    6.0
 * @license    http://www.diafan.ru/license.html
 * @copyright  Copyright (c) 2003-2016 OOO «Диафан» (http://www.diafan.ru/)
 */

if (! defined('DIAFAN'))
{
    $path = __FILE__; $i = 0;
	while(! file_exists($path.'/includes/404.php'))
	{
		if($i == 10) exit; $i++;
		$path = dirname($path);
	}
	include $path.'/includes/404.php';
}

class Clauses_install extends Install
{
    /**
     * @var string название
     */
    public $title = "Статьи";

    /**
     * @var array таблицы в базе данных
     */
    public $tables = array(
        array(
            "name" => "clauses",
            "comment" => "Статьи",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "name",
                    "type" => "TEXT",
                    "comment" => "название",
                    "multilang" => true,
                ),
                array(
                    "name" => "act",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "показывать на сайте: 0 - нет, 1 - да",
                    "multilang" => true,
                ),
                array(
                    "name" => "map_no_show",
                    "type" => "ENUM( '0', '1' ) NOT NULL DEFAULT '0'",
                    "comment" => "не показывать на карте сайта: 0 - нет, 1 - да",
                ),
                array(
                    "name" => "changefreq",
                    "type" => "ENUM( 'always', 'hourly', 'daily', 'weekly', 'monthly', 'yearly', 'never' ) NOT NULL DEFAULT 'always'",
                    "comment" => "Changefreq для sitemap.xml",
                ),
                array(
                    "name" => "priority",
                    "type" => "VARCHAR(3) NOT NULL DEFAULT ''",
                    "comment" => "Priority для sitemap.xml",
                ),
				array(
					"name" => "noindex",
					"type" => "ENUM('0','1') NOT NULL DEFAULT '0'",
					"comment" => "не индексировать: 0 - нет, 1 - да",
				),
                array(
                    "name" => "created",
                    "type" => "INT(10) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "дата создания",
                ),
                array(
                    "name" => "date_start",
                    "type" => "INT(10) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "дата начала показа",
                ),
                array(
                    "name" => "date_finish",
                    "type" => "INT(10) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "дата окончания показа",
                ),
                array(
                    "name" => "cat_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор основной категории из таблицы {clauses_category}",
                ),
                array(
                    "name" => "site_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор страницы сайта из таблицы {site}",
                ),
                array(
                    "name" => "keywords",
                    "type" => "VARCHAR(250) NOT NULL DEFAULT ''",
                    "comment" => "ключевые слова, тег Keywords",
                    "multilang" => true,
                ),
                array(
                    "name" => "descr",
                    "type" => "TEXT",
                    "comment" => "описание, тэг Description",
                    "multilang" => true,
                ),
                array(
                    "name" => "canonical",
                    "type" => "VARCHAR(100) NOT NULL DEFAULT ''",
                    "comment" => "канонический тег",
                    "multilang" => true,
                ),
                array(
                    "name" => "title_meta",
                    "type" => "VARCHAR(250) NOT NULL DEFAULT ''",
                    "comment" => "заголовок окна в браузере, тег Title",
                    "multilang" => true,
                ),
                array(
                    "name" => "anons",
                    "type" => "TEXT",
                    "comment" => "анонс",
                    "multilang" => true,
                ),
                array(
                    "name" => "anons_plus",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "добавлять анонс к описанию: 0 - нет, 1 - да",
                    "multilang" => true,
                ),
                array(
                    "name" => "text",
                    "type" => "LONGTEXT",
                    "comment" => "описание",
                    "multilang" => true,
                ),
                array(
                    "name" => "timeedit",
                    "type" => "INT(10) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "время последнего изменения в формате UNIXTIME",
                ),
                array(
                    "name" => "admin_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "пользователь из таблицы {users}, добавивший или первый отредктировавший статью в административной части",
                ),
                array(
                    "name" => "access",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "доступ ограничен: 0 - нет, 1 - да",
                ),
                array(
                    "name" => "theme",
                    "type" => "VARCHAR(50) NOT NULL DEFAULT ''",
                    "comment" => "шаблон страницы сайта",
                ),
                array(
                    "name" => "view",
                    "type" => "VARCHAR(50) NOT NULL DEFAULT ''",
                    "comment" => "шаблон модуля",
                ),
                array(
                    "name" => "sort",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "подрядковый номер для сортировки",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
                "KEY site_id (site_id)",
            ),
        ),
        array(
            "name" => "clauses_category",
            "comment" => "Категории статей",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "name",
                    "type" => "TEXT",
                    "comment" => "название",
                    "multilang" => true,
                ),
                array(
                    "name" => "act",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "показывать на сайте: 0 - нет, 1 - да",
                    "multilang" => true,
                ),
                array(
                    "name" => "map_no_show",
                    "type" => "ENUM( '0', '1' ) NOT NULL DEFAULT '0'",
                    "comment" => "не показывать на карте сайта: 0 - нет, 1 - да",
                ),
                array(
                    "name" => "changefreq",
                    "type" => "ENUM( 'always', 'hourly', 'daily', 'weekly', 'monthly', 'yearly', 'never' ) NOT NULL DEFAULT 'always'",
                    "comment" => "Changefreq для sitemap.xml",
                ),
                array(
                    "name" => "priority",
                    "type" => "VARCHAR(3) NOT NULL DEFAULT ''",
                    "comment" => "Priority для sitemap.xml",
                ),
				array(
					"name" => "noindex",
					"type" => "ENUM('0','1') NOT NULL DEFAULT '0'",
					"comment" => "не индексировать: 0 - нет, 1 - да",
				),
                array(
                    "name" => "parent_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор родителя из таблицы {clauses_category}",
                ),
                array(
                    "name" => "count_children",
                    "type" => "SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "количество вложенных категорий",
                ),
                array(
                    "name" => "site_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор страницы сайта из таблицы {site}",
                ),
                array(
                    "name" => "keywords",
                    "type" => "VARCHAR(250) NOT NULL DEFAULT ''",
                    "comment" => "ключевые слова, тег Keywords",
                    "multilang" => true,
                ),
                array(
                    "name" => "descr",
                    "type" => "TEXT",
                    "comment" => "описание, тэг Description",
                    "multilang" => true,
                ),
                array(
                    "name" => "canonical",
                    "type" => "VARCHAR(100) NOT NULL DEFAULT ''",
                    "comment" => "канонический тег",
                    "multilang" => true,
                ),
                array(
                    "name" => "title_meta",
                    "type" => "VARCHAR(250) NOT NULL DEFAULT ''",
                    "comment" => "заголовок окна в браузере, тег Title",
                    "multilang" => true,
                ),
                array(
                    "name" => "anons",
                    "type" => "TEXT",
                    "comment" => "анонс",
                    "multilang" => true,
                ),
                array(
                    "name" => "anons_plus",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "добавлять анонс к описанию: 0 - нет, 1 - да",
                    "multilang" => true,
                ),
                array(
                    "name" => "text",
                    "type" => "TEXT",
                    "comment" => "описание",
                    "multilang" => true,
                ),
                array(
                    "name" => "sort",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "подрядковый номер для сортировки",
                ),
                array(
                    "name" => "timeedit",
                    "type" => "INT(10) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "время последнего изменения в формате UNIXTIME",
                ),
                array(
                    "name" => "admin_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "пользователь из таблицы {users}, добавивший или первый отредктировавший категорию в административной части",
                ),
                array(
                    "name" => "access",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "доступ ограничен: 0 - нет, 1 - да",
                ),
                array(
                    "name" => "theme",
                    "type" => "VARCHAR(50) NOT NULL DEFAULT ''",
                    "comment" => "шаблон страницы сайта",
                ),
                array(
                    "name" => "view",
                    "type" => "VARCHAR(50) NOT NULL DEFAULT ''",
                    "comment" => "шаблон модуля",
                ),
                array(
                    "name" => "view_element",
                    "type" => "VARCHAR(50) NOT NULL DEFAULT ''",
                    "comment" => "шаблон модуля для элементов в категории",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
                "KEY parent_id (parent_id)",
                "KEY site_id (site_id)",
            ),
        ),
        array(
            "name" => "clauses_category_rel",
            "comment" => "Связи статей и категорий",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "element_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор статьи из таблицы {clauses}",
                ),
                array(
                    "name" => "cat_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор категории из таблицы {clauses_category}",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
                "KEY cat_id (`cat_id`)",
            ),
        ),
        array(
            "name" => "clauses_category_parents",
            "comment" => "Родительские связи категорий статей",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "element_id",
                    "type" => "INT( 11 ) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор категории из таблицы {clauses_category}",
                ),
                array(
                    "name" => "parent_id",
                    "type" => "INT( 11 ) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор категории-родителя из таблицы {clauses_category}",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM( '0', '1' ) NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
            ),
        ),
        array(
            "name" => "clauses_counter",
            "comment" => "Счетчик просмотров статей",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "element_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор статьи из таблицы {clauses}",
                ),
                array(
                    "name" => "count_view",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "количество просмотров",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
                "KEY element_id (`element_id`)",
            ),
        ),
        array(
            "name" => "clauses_rel",
            "comment" => "Связи похожих статей",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                    "comment" => "идентификатор",
                ),
                array(
                    "name" => "element_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор статьи из таблицы {clauses}",
                ),
                array(
                    "name" => "rel_element_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                    "comment" => "идентификатор связанной статьи из таблицы {clauses}",
                ),
                array(
                    "name" => "trash",
                    "type" => "ENUM('0', '1') NOT NULL DEFAULT '0'",
                    "comment" => "запись удалена в корзину: 0 - нет, 1 - да",
                ),
            ),
            "keys" => array(
                "PRIMARY KEY (id)",
            ),
        ),
    );

    /**
     * @var array записи в таблице {modules}
     */
    public $modules = array(
        array(
            "name" => "clauses",
            "admin" => true,
            "site" => true,
            "site_page" => true,
        ),
    );

    /**
     * @var array меню административной части
     */
    public $admin = array(
        array(
            "name" => "Статьи",
            "rewrite" => "clauses",
            "group_id" => "1",
            "sort" => 6,
            "act" => true,
			"add" => true,
			"add_name" => "Статью",
            "docs" => "http://www.diafan.ru/moduli/stati/",
            "children" => array(
                array(
                    "name" => "Статьи",
                    "rewrite" => "clauses",
                    "act" => true,
                ),
                array(
                    "name" => "Категории",
                    "rewrite" => "clauses/category",
                    "act" => true,
                ),
                array (
                    'name' => 'Статистика',
                    'rewrite' => 'clauses/counter',
                    'act' => true,
                ),
                array(
                    "name" => "Настройки",
                    "rewrite" => "clauses/config",
                ),
            )
        ),
    );

    /**
     * @var array страницы сайта
     */
    public $site = array(
        array(
            "name" => array('Статьи', 'Articles'),
            "module_name" => "clauses",
            "rewrite" => "clauses",
            "menu" => 1,
            "parent_id" => 2,
        ),
    );

    /**
     * @var array настройки
     */
    public $config = array(
        array(
            "name" => "images_element",
            "value" => "1",
        ),
        array(
            "name" => "list_img_element",
            "value" => "1",
        ),
        array(
            "name" => "use_animation",
            "value" => "1",
        ),
        array(
            "name" => "format_date",
            "value" => "2",
        ),
        array(
            "name" => "nastr",
            "value" => 10,
        ),
		array(
			"name" => "nastr_cat",
			"value" => 10,
		),
        array(
            "name" => "count_list",
            "value" => "3",
        ),
        array(
            "name" => "count_child_list",
            "value" => "2",
        ),
        array(
            "name" => "children_elements",
            "value" => "1",
        ),
        array(
            "name" => "counter",
            "value" => "1",
        ),
        array(
            "name" => "images_variations_element",
            "value" => 'a:2:{i:0;a:2:{s:4:"name";s:6:"medium";s:2:"id";i:1;}i:1;a:2:{s:4:"name";s:5:"large";s:2:"id";i:3;}}',
        ),
        array(
            "name" => "cat",
            "value" => "1",
        ),
        array(
            "name" => "comments",
            "value" => "1",
        ),
    );

    /**
     * @var array демо-данные
     */
    public $demo = array(
        'clauses_category' => array(
            array(
                'id' => 1,
                'name' => array('Помощь в выборе', 'Help in a choice'),
                'text' => array('<p>Здесь у нас новости общего характера</p>'),
                'rewrite' => 'clauses/pomosch-v-vybore',
            ),
            array(
                'id' => 2,
                'name' => array('О походах', 'About campaigns'),
                'text' => array('<p>Самые последние новости о наших зверятах</p>'),
                'rewrite' => 'clauses/o-pokhodakh',
            ),
            array(
                'id' => 3,
                'name' => array('Инструкции', 'Instructions'),
                'text' => array('<p>Самые последние новости о наших зверятах</p>'),
                'rewrite' => 'clauses/instruktsii',
            ),
        ),
        'clauses' => array(
            array(
                'id' => 7,
                'cat_id' => 1,
                'name' => array('Чем отличаются костюмы Буран и Буран N ?'),
                'anons' => array('<p>Полностью сохранив свою узнаваемость и качество, легендарный «Буран» дополнен весьма полезными характеристиками, с учётом современной зимней и рыболовной моды:</p>'

                ),
                'text' => array('<p>1.Куртка и полукомбинезон Буран N изготовлены их ткани Nylon Taslan с мембранным покрытием 3000/3000 (паропроницаемость/водостойкость). Современная дышащая мембранная ткань Nylon Taslan расширит температурный диапазон применения костюма.<br />2.В куртке Буран N двухшовный рукав с эффектом локтевого объёма. Манжеты регулируются эластичной тесьмой с «липучкой». Свобода движения - анатомический крой рукава создаст комфорт в движениях. А липучки на манжетах освободят кисть руки.<br />3.Полукомбинезон Буран N «оборудован» настроченными наколенниками с карманом на молнии для вставки вкладышей. Берегите колени! Мы продумали защиту коленей специально для рыбаков - полукомбинезон Буран N снабжен кармашком для наколенника, который просто необходим, если вы опускаете колено на снег зимой.<br /><br />4.Куртка Буран N и полукомбинезон Буран N предлагаются не костюмом-комплектом, а как самостоятельные изделия. Теперь каждый может собрать свой костюм Буран N самостоятельно, точно подобрав размер куртки и полукомбинезона и выбрав именно то цветовое сочетания, которое ему по душе. Уже есть Комбинезон? Не подходит размер куртки? Теперь вы можете купить куртку и комбинезон раздельно!<br /><br />Также Буран N сохранил все те особенности, за которые его так любят!<br /><br /><strong>Куртка Буран</strong><br />- центральная застежка на 2-х замковую молнию<br />- 8 карманов<br />- объёмный накладной карман на рукаве<br />- по талии и низу куртки кулиски с эластичным шнуром для регулировки объёма<br />- воротник-стойка, внутренний воротник и верхняя часть внутренней ветрозащитной планки – из флиса.<br />- капюшон съёмный, на молнии, регулируемый по объёму эластичным шнуром со стопорами<br />- жилет-подстёжка, который можно использовать как самостоятельный элемент одежды.<br /><br /><strong>Полукомбинезон Буран</strong><br />- центральная застежка на 2-замковую молнию<br />- два грузовых и два прорезных кармана на молнии<br />- спинка утеплена флисом<br />- эластичные баковые вставки, для удобной посадки по фигуре<br />- бретели с эластичной тесьмой.<br /><br /></p>',

                ),
                'images' => array(
                    '289_chem-otlichayutsya-kostyumy-bur.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/chem-otlichayutsya-kostyumy-buran-i-buran-n-',
            ),
            array(
                'id' => 6,
                'cat_id' => 1,
                'name' => array('Женское термобельё – пора делать выбор!'),
                'anons' => array('<p>Женщине важно любить себя и заботиться о себе даже в мелочах.</p>'),
                'text' => array('<p>2. А здоровье и комфорт – это вовсе не мелочи.<br /><br />3. Термобелье женское убережет от простуд и будет приятно согревать ваш организм в любую погоду.<br /><br />4. Термобелье женское NOVA TOUR– это нижнее белье, изготовленное из специальных высокотехнологичных материалов.<br /><br />5. За счет особой структуры ткани и плоских швов оно плотно облегает фигуру и будет совершенно незаметно под любым силуэтом верхней одежды, а значит, вы всегда будете выглядеть элегантно.<br /><br />6. Термобелье прекрасно отводит влагу и быстро сохнет.<br /><br />7. Функциональное белье удобно и приятно к телу.<br /><br />8. Отлично подойдет такое белье и для занятий спортом и прогулок на открытом воздухе даже в самую холодную погоду&hellip;<br /><br />Почему причин всего лишь 8, спросите вы? Так это же знак бесконечности! О хороших вещах можно говорить бес-ко-неч-но!!! Но не стоит тратить время на беседы. Надо спешить пополнить свой гардероб к зимнему сезону. В коллекции NOVA TOUR женское термобельеПоларис и Актив.<br /><br />Настоящие модницы оценят результат Подмигиваю<br /></p>'),
                'images' => array(
                    '288_zhenskoe-termobelyo--pora-.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/zhenskoe-termobelyo--pora-delat-vybor',             
            ),
            array(
                'id' => 5,
                'cat_id' => 1,
                'name' => array('Помощь в выборе спального мешка'),
                'anons' => array('<p>Спальник!<strong> </strong>Что возникает при этом слове у «правоверного» туриста (путешественника, рыбака, охотника, дачника).</p>'),
                'text' => array('<p>Спальник – это, прежде всего сладкий утренний сон в тепле, когда сквозь тентпалатки вашего лица касается первый робкий луч! (Заметим в скобках, что особенно здорово, если это будет именно луч солнца, а не дождевая струйка воды сквозь протекший шов палатки. Подробнее как грамотно купить палатку, после чего уже не париться насчет наводнения (землетрясения, торнадо и метеоритного дождя) смотрите тут.<br /><br />Но, чтобы находясь на природе, проснуться в тепле и отличном расположении духа, вам нужно сначала правильно выбрать и купить спальник. Тот самый! Единственный и неповторимый! J Что же для этого нужно?<br /><br />Прежде всего, необходимо понимание для чего вам спальник и где вы будете в нем спать!<br /><br />Если на даче в легком холодке (в мае или в сентябре) – вам подойдет спальник типа одеяло. Такие как «Одеяло», «Одеяло с подголовником», «Пионер». А также – спальник «Сахалин». Легкие дешевые и компактные. Для «крупных личностей и широких натур» рекомендуем спальник шириной 100см (стандартная широина: 70-80). У таких спальников есть «говорящая» приставка к названию: XL. Выбирайте и не промахнетесь!<br /><br />Если же у вас с российскими просторами серьезные отношения (например недельный тут на Байкале или сплав в верховьях плата Путорана), то линейка теплых коконов от компании NT именно то, что вам подойдет. Например, спальник Оймякон. (Чувствуете, как от одного названия сразу потеплело на душе!) Сразу представили полугодовую ночь за полярным кругом, шаманов с бубнами на собачьих упряжках. Все правильно! Экстремальная температура использования до минус сорока градусов (имеется ввиду по Цельсию и снаружи, а не то, что внутрь!)<br /><br />Для тех, кому минус сорок противопоказано, ( кто рассчитывает «всего лишь» на минус тридцать ) подойдет спальник «Арктика» или спальник «Ямал», спальник «Ямал XL» . А для минус 20-25 – спальник «Тамерлан», спальник «Сибирь», спальник «Альбаган». Все подробности где и как купить спальник можно узнать здесь.<br /><br />Отличительная деталь спальника для серьезных отношений – это наличие утепленного капюшона. Ведь голова – это наше самое ценное, а как легко ее бывает потерять!<br /><br />Кстати! После того, как вы определились для чего вам спальник и где вы будете в нем спать, остается еще немаловажный вопрос с кем! (Специальная сноска для полиции нравов и детского интернета! Дальше читать можно всем!)<br /><br />Потому что если вы собираетесь спать, например, втроем в одной палатке, то можно здорово сэкономить на стоимости и весе и вместо трех спальников обойтись всего двумя! (Менеджеры и продавцы проклянут меня за это, но вам я все равно расскажу, как это сделать!J)<br /><br />Все очень просто! Выбираете два спальника таким образом, чтобы они состегивались вместе. (В такие развернутые и соединенные между собой спальники вполне влезут два не слишком крупных рыбака и один охотник, например). Для облегчения задачи заботливый производитель, (такой как, например компания NT) маркирует спальник соответствующей буквой L(левый) или R(правый). Т.о. если собираетесь спальники состегивать вместе, то нужно выбирать «разнополые» спальники R и L.<br /><br />Чаще всего состегивают вместе спальники типа «одеяло» - т.е. скроенный прямоугольно. В линейке NT это модель «Альбаган», но можно стыковать и «коконы».<br /><br />Сколько существует спальник, столько же времени идет дискуссия, о том, какая конструкция реально лучше – кокон или одеяло! Ответ на этот наиважнейший вопрос современности каждый должен сделать сам, однако очевидно следующее: Если для вас критичен вес, то выбирайте кокон – в нем, кстати, при прочих равных будет теплее. (Именно поэтому все альпинисты, спелеологи и экстремалы предпочитают именно кокон). Если же вес не имеет значения, а на первом месте – удобство и комфорт – покупайте спальник типа одеяло! В нем вы не будете чувствовать себя спеленатым а-ля египетская мумия. Можно и поворочаться и ноги разложить повольготнее! Идеальный вариант для кемперов, джиперов и всех им сочувствующих!<br /><br />Второй повод для дискуссии – наполнитель. Тут опять туристический мир разделился на два лагеря: Одни отдают предпочтение традиционному пуху, вторые – синтетике. У наполнителя из пуха (лучше всего – гусиного или гагачьего) важнейшей составляющей является соотношение пуха к перу. Чем выше содержание пуха – тем теплее и лучше, но и цена выше. Синтетика характеризуется в основном плотностью и измеряется в граммах на метр квадратный. Соответственно, чем выше показатель (например 250гр/м) тем теплее, но и объем спальника (и соответственно его размер) разрастается пропорционально! Если же спальник двухслойный, то в сложенном виде влезает уже не во всякий рюкзак, что опять же некритично, если вы выезжаете на природу с целым прицепом, куда легко помещаются ружья, палатки, друзья, спальники, жены, удочки, дети и прочий необходимый скарб. (Заметим, что фирменные спальники NT обязательно комплектуются компрессионным мешком и мешком для хранения! Остерегайтесь дешевых подделок!)<br /><br />Последнее время в синтетике наблюдается настоящая гонка технологий и терминологий. От самых простых – синтепона, холофайбера, до дышащих Hi-Isoterm Technofiber и совсем уж космического (особенно по цене!) Primaloft. Не вдаваясь в детали – все они суть крученые синтетические нити с мельчайшими внутренними каналами для сохранения в них изолирующего слоя воздуха – до сих пор непревзойденного изолятора!<br /><br />Кроме прочего следует помнить, что пух легче намокает и дольше сохнет по сравнению с синтетикой! В общем – дискуссия продолжается!<br /><br />Какой бы конструкции спальника вы ни отдали предпочтение, обратите внимание, что у каждой модели спальника NT из коллекции этого года есть свой оригинальный узор! Один навеян мотивами скандинавских рун, другой – наскальными петроглифами майя, в третьем – шумерская вязь, в четвертом - тотемные символы народов севера. Не многие производители придают своим спальникам такое запоминающееся, неповторимое лицо!<br /><br />В заключение – еще один маленький совет-напоминание! Какой бы надежной ни была Ваша палатка, Какой бы теплый спальник вы ни выбрали, без качественного коврика под ним (т.е. под Вами, дорогой турист, путешественник, рыбак, охотник!) Вам не обойтись! Выбрать легкий, компактный и при этом полностью теплоизолирующий туристический коврик вам поможет интернет-магазин компании NT!<br /><br />Пожалуйста, заходите и чувствуйте себя по-настоящему дома!</p>'),
                'images' => array(
                    '287_pomosch-v-vybore-spalnogo-m.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/pomosch-v-vybore-spalnogo-meshka',  
            ),
            array(
                'id' => 4,
                'cat_id' => 1,
                'name' => array('Советы по выбору палатки'),
                'anons' => array('<p>Друзья! Скажите честно, есть ли среди вас те, кто ни разу не ночевал в палатке? Искренне надеюсь, что если я запущу голосование, ответ «нет» будет стопроцентным! Нет среди нас таких людей! И это весьма обнадеживает!</p>'),
                'text' => array('<p>Потому что если вы зашли сюда для того чтобы купить палатку, то нам уже нет необходимости объяснять, что такое палатка. Зато мы с удовольствием поговорим на тему, какие бывают палатки, как выбрать и чем отличаются палатки NT от всех других.<br /><br />Итак!<br /><br /><strong>Какую выбрать палатку?</strong><br /><br /><strong>Палатки туристические (их еще называют треккинговые)</strong> – это палатки, которые стоит выбирать, если вы идете в пеший поход и собираетесь нести их на себе (например, в рюкзаке!)<br /><br />История палаток столь же древняя, как и история цивилизации! Как только человеку надоело жить на одном месте – в пещере, завешенной шкурами животных (да простят нам эту фразу Greenpeace и J) так тут же перед ним, как перед первым путешественником встал вопрос: Как сделать так, чтобы не путешественник был привязан к дому, а наоборот – дом к путешественнику; не обременял, а наоборот – помогал. Тут же нашелся и ответ! Так появились войлочные юрты, шалаши, чумы, яранги и прочие мобильные, быстровозводимые жилища! С тех пор все и началось! Прошло совсем немного времени, и вот совершенство практически достигнуто! К вашим услугам палатки Смарт или Эксплорер от NT<br /><br />Собрались на воскресный пикник или хотите купить палатку для зимней или летней рыбалки? Для летней – линейка палаток Тайга! Классическая двускатная!<br /><br />Двускатные палатки – это классика жанра! С ней мы знакомы еще с незапамятных времен, когда самой «продвинутой» была польская палатка-домик из оранжевого или желтого нейлона. Такие палатки собирались на алюминиевых трубчатых каркасах и были жутко модными! А еще к ним в комплекте шли чудесные плоские алюминиевые колышки! Моя бабушка рыхлила ими грядку на огороде и была просто счастлива! (кажется, эти палатки назывались Campus (да здравствует черный PR!!!:J)<br />Эти палатки были гораздо моднее, чем пресловутая двускатная оливковая «брезентуха», пошитая из отходов, оставшихся после раскройки танковых чехлов для «оборонки»!J<br /><br />Если же вы любите отдыхать на широкую ногу (кстати, не забудьте посмотреть, какой широкий в нашем интернет-магазине выбор обуви!) то специально для любителей отдыха с комфортом, мы предлагаем кемпинговые палатки NT<br /><br />Помните диалог из фильма «Иван Васильевич меняет профессию»?<br /><br />- Где живете?<br /><br />- В палатах!<br /><br />Так вот уровень комфорта, который способны предложить кемпинговые палатки NT, такой, что и царю не стыдно было бы поселиться в одной из них! Например, в палатке Фиеста 4, 5 или Вирджиния 4,6<br /><br /><br />А может быть вам необходима палатка для восхождения на ближайший «восьмитысячник?» Тогда это уже случай серьезный, но тоже не безнадежноJ!<br /><br /><br />- Я спросил тебя, с какой палаткой в горы вы?<br /><br />- Конечно с Памиром! Или с Тибетом! – рассмеялась ты и взяла с собой<br /><br /><br />Вот мы практически и определились с основными группами палаток по их назначению:<br /><br />Туристические(треккинговые)<br /><br />Палатки для рыбалки (зимней и летней)<br />Кемпинговые палатки<br /><br />Экстремальные палатки<br /><br />Отдельной темой предлагаю считать бани, тенты, беседки, а также аксессуары и ремнаборы к ним и к палаткам.<br /><br />Какая конструкция лучше?<br /><br />Тут, как вы понимаете, однозначного ответа нет! Сколько людей – столько и предпочтений и палатка в это смысле не исключение!<br /><br />В самых общих чертах можно сказать следующее:<br /><br />- двускатные классические<br /><br />- купольные<br /><br />- купольные с тамбуром<br /><br />- полубочки<br /><br /><br /><strong>Некоторые советы при выборе палатки!</strong><br /><br />- Бывает, что палатка отлично выглядит на картинке, но в жизни собрать ее настолько сложно, что если вы не заканчивали геологический (или космический) факультет, то вряд ли справитесь! Совет: попросите продавца поставить ее в торговом зале! В хороших магазинах вам обязательно пойдут навстречу, а в некоторых палатки уже стоят собранные! (летом собрать палатку можно в т.ч. на улице!) Ну а если вам отказано, лучше подыщите другой магазин!<br /><br />- Итак, вам попался клиентоориентированный (т.е. адекватный) продавец. Он видит, что вы настроены серьезно и ставит при вас палатку! Вот он открыл чехол! Внимание! Следите за мелочами! Сразу могут быть видны неаккуратные швы или неподобранные разлохмаченные края ткани! Стойки могут быть покрыты ржавчиной или белесым окислившимся налетом. С одной стороны – это не говорит о том, что это плохая марка палаток! Просто данную конкретную палатку могло, например, залить при наводнении на складе. Попросите открыть вторую, максимум третью. Если картина та же – смело говорите «Спасибодосвидания»!<br /><br />- Открыли чехол: Строчки ровные, швы проклеены и подобраны, ткань ripstop стойки сияют как начищенные. Обратите внимание легко ли продавец собрал палатку! Он ведь делает это гораздо чаще, чем вы! Посмотрите в каком порядке он собирает палатку (сначала каркас, потом крепит к нему тент или одновременно или еще как-то), есть ли инструкция и понятна ли она вам! Последнее время появились совсем экзотические варианты типа надувных каркасов или автоматически раскрываемых каркасов. Конструкции спорные ввиду сложности надежного промышленного исполнения!<br /><br />- Обратите внимание на то один или два входа/выхода у палатки! В жару один выход – это мало! А вот если два – вам не будет жарко! Вентиляционные клапаны – достаточно ли они удобны для открывания. Кстати, очень здорово. Когда входы настеж, а комаров нет – потому что есть возможность закрыть входы, окна и клапана антимоскитной сеткой на молнии!<br /><br />- Вместимость тамбура – также немаловажный показатель! Чем больше размер тамбура – тем больший бардак в хранении вещей, рюкзаков, и т.д. вы сможете себе позволить!(Не стесняйтесь – все туристы делают это!J) Здорово если есть выдвижной навес на вертикальных стойках! Под ним удобно располагать походную кухню или в его тени расставить кемпинговую мебель!<br /><br />- Если вы отдыхаете на природе с детьми, есть смысл обратить внимание на палатку с двумя спальными отделениями и тамбуром между ними! Тогда вы сможете уложить их спать отдельно и, например, пораньше. И никаких проблем!<br /><br />- Дуги! Металлические – из сплавов алюминия с ванадием - как правило легче фиберглассовых или дюраполовых. Стальные – вчерашний день! В линейке NT и Greenel из стали сделаны только вертикальные прямые стойки (не дуги!). Если вес не критичен (например у вас автовыезд на рыбалку-пикник) выбирайте дюрапол – современный композитный материал улучшенной формулы!<br /><br />- Обращайте внимание на характеристику водяного столба или влагостойкость ткани! Последнее время наметилась настоящая гонка показателей (не всегда адекватных реальности!) Заявляют и 6000 и более! Компания NT предлагает только самые современные материалы, конструкции и технологии. Ткани сертифицированы по многим показателям и соответствуют заявленным характеристикам!<br /><br />Компания NT предлагает только самые современные материалы, конструкции и технологии. Ткани сертифицированы по многим показателям и соответствуют заявленным характеристикам!</p>'),
                'images' => array(
                    '286_sovety-po-vyboru-palatki.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/sovety-po-vyboru-palatki',  
            ),
            array(
                'id' => 3,
                'cat_id' => 1,
                'name' => array('Отдых на природе с комфортом? ДА! Как выбрать кемпинговую мебель?'),
                'anons' => array('<p>Ну что же, дорогие туристы, рыбаки, охотники, дачники («хулиганы, тунеядцы и прочие граждане!») Как говорится – Шаг вперед! Начинаем разговор о мебели!</p>'),
                'text' => array('<p>Мы не будем рассказывать о том, какая мебель вам нужна! Это вы решите сами!<br /><br />Мы расскажем о том, какая мебель бывает в принципе! Прежде всего, давайте поделим мебель на кемпинговую и остальную! (Про «остальную» вам расскажут в «Трех кашалотах» «Агромадах» и прочих скучных и пыльных местах, далеких от нашей актуальной outdoor-темы! Давайте договоримся, что мебель – (и прежде всего мебель Greenell от NT!) – это мебель для ленивых людей, ведущих активный образ жизни! (сразу возникают картины живой природы и наши с вами посиделки и пикники на ней!)<br /><br />Потому что даже взять и вынести Кресло FС10 из дачного домика на улицу в тенек – это уже подвиг активности! Особенно в такую жару, какая нынче бывает летом в России! Итак, взяли и вынесли! Теперь сидите в прохладе и наслаждайтесь свежим ветерком и отсутствием запаха горящих торфяников! Не смотрите, какой у этого кресла надежный алюминиевый профиль 32*20мм! Подумаешь, что он специально разработан для грузных людей и без труда выдержит человека массой до 120 кг! (Мало? Возьмите в одну руку бутылочку пива, а в другую удочку или воблу! Взяли? Кресло все еще держит? Теперь достаточно?)<br /><br />Не обращайте внимание на отличное качество заклепок и надежность шарнирных узлов! На анатомические пластиковые подлокотники! В самом деле – такая мелочь! Ножки «обуты» в пластмассовые колпачки – это чтобы не царапать только что отциклеванный пол на вашей чудесной дачной веранде и не проваливаться в земляной грунт, когда вы сидите в нем вне дома на рыбалке или в лесу (т.е. outdoor)<br /><br />Что касается оливкового сетчатого полиэстера, на который вы так удачно и надежно налегаете уставшей от офисных кресел спиной, то это и вовсе не повод для упоминания! Вы просто отдыхайте, а об остальном позаботились конструкторы мебели Greenell!<br /><br />Например, мы позаботились о том, чтобы вы могли менять угол наклона спинки согласно вашему желанию.<br /><br />У кресла F10 есть практически идентичные «собратья»! Это кресла FC8 и FC9!<br /><br />«Девятка» собрана на стальном окрашенном порошковой краской каркасе (Ф22мм). Подлокотники из гипоаллергенного пластика. Спина помягче и потеплее (полиэстер 600D), т.е. отлично подойдет и для ранней осени! Угол наклона спины также регулируется. 120 кг «живого» веса для «девятки» не проблема, а само кресло весит чуть более 5 кг.<br /><br />«Восьмерка» обладает всеми преимуществами «десятки», только весит на полкило меньше(3,7кг) т.к. каркас сделан из алюминиевых трубок (Ф22). При этом выдерживает те же 120 кг. Тот же легкий сетчатый вентилируемый легко моющийся полиэстер. Спинка не регулируется, зато и купить в интернет-магазине NT это кресло можно дешевле.<br /><br />И у «девятки» и у «восьмерки» ножки для большей устойчивости и надежности соединены между собой! <br />Ну а для тех, кто, взяв (для веса) бутылочку пива, не знает, куда ее поудобней пристроить – пожалуйста! Мы подумали и об этом! У кресла Greenell FC7 – под подлокотником вшит специальный прочный карман! Стоит протянуть к нему руку и.. (далее думаю не нужно объяснять!)<br /><br />Кстати! Запомните эту модель!(цифру 7 – очень легко запомнить – это вообще счастливое число) Ножки у «семерки» эргономичной формы. Плавные линии широких алюминиевых подлокотников радуют глаз, а в жару приятно холодят руку и не «припотевают» к ней! Пластик качественный, все узлы надежны и конструктивно продуманы. Сиденье и спинка скроены из единого полотна – полиэстер 600D( что удобно и практично!). Края и места соединений ткани с металлом для большей прочности прошиты тесьмой. Весит «семерка» 3,7 кг, легко выдержит вас, если вы весите до 100кг! Складывается в тубус (входит в комплект!).<br /><br />Более подробные характеристики, а также где, с какими скидками и как можно купить кресло Greenell FC7 смотрите тут.<br /><br />Стул FC6 – это классика «рыболовного жанра»! «Шестерка» популярна тем что<br /><br /> во-первых – удобно складывается в тубус и забрасывается в багажник (под кровать, в палатку, на антресоль)<br /> во-вторых спинка у «шестерки» удлиненная и практически переходит в подголовник (так что соснуть часок другой в ожидании поклевки можно с особым комфортом!)<br /> в-третьих «шестерка» - самый легкий стальной стул (собственный вес - 3,2 кг, держит вес 100кг)<br /> в подлокотник вшит все тот же пресловутый подстаканник-подбутылочник! (Опция незаменима, (развивать тему не будем, т.к. на этом месте могла быть реклама вашего любимого пива!)<br /><br />Более подробные характеристики, а также где, с какими скидками и как можно купить стул Greenell FC6 смотрите тут.<br /><br />Пара стульев FC4 и FC3 – проверенные надежные и популярные модели складной мебели! Мощные алюминиевые трубы сечением 25мм, легкость и удобство складывания (и что немаловажно – раскладывания!) Подлокотники из цветного неопрена.<br /><br />Запомнить очень просто! «Трешка» весит 3 кг, «четверка» 3,3кг (триста грамм добавляет удобный откидной столик, хотя иногда все содержимое с него летит на землю. Это значит, что «подсекая» поклевку, вы взмахнули рукой!. В этом смысле «мягкий» сетчатый стакан на «шестерке» и «семерке» удобнее. В нем бутылка может слегка расплескаться, но на землю точно не улетит!)<br /><br />Более подробные характеристики, а также где, с какими скидками и как можно купить стулья Greenell FC3FC4 смотрите тут.<br /><br />Есть в коллекции Greenell и пара моделей туристических табуреток. Это так сказать для самых экономных или для тех кому вес критичен!(например, когда все несут на себе в рюкзаке)<br /><br />Трехногая алюминиевая «единичка» - модель проверенная временем. По популярности с «единичкой» может соперничать только модель входящая в комплект FTFS-1 от Greenell (кстати, в этом комплекте аж четыре табуретки!) Модель этой табуретки хорошо знакома туристам (и вообще нашему народу) еще с приснопамятных советских времен!<br /><br />Складной алюминиевый стол за которым никому не будет тесно, а уж сколько всего можно на нем разложить(нарезать, откупорить, разлить и принять!). А главное, утром, выбравшись из палатки вы все это с легкостью сможете убрать обратно в сумку (входит в комплект!) и забыть до следующих выходных!<br /><br />Более подробные характеристики столов и табуретов, а также где, с какими скидками и как их можно купить смотрите тут.<br /><br />Ну и в завершении то, без чего отдых – не отдых. В самом деле! Если не на чем прилечь позагорать или спокойно и без помех досмотреть цветные сны – то что это за отдых! Кровати от Greenell в этом смысле именно то, что нужно! Легкие, надежные стальные BD5 и BD6 и сверхнадежная алюминиевая BD3! Все рассчитаны не менее чем на 120 кг «сонной массы».<br /><br />Более подробные характеристики кроватей, а также где, с какими скидками и как их можно купить смотрите тут.<br /><br />Очень надеемся, что этот краткий экскурс помог вам самостоятельно определиться с выбором. Если же вопросы все еще остались (например, какую скидку я получу в дальнейшем, купив сейчас мебель Greenell в инетмаге NT) приглашаем вас задать вопрос нашему специалисту.<br /><br />Мы всегда готовы помочь!<br /><br /></p>'),
                'images' => array(
                    '285_otdykh-na-prirode-s-komforto.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/otdykh-na-prirode-s-komfortom-da-kak-vybrat-kempin',
            ),
            array(
                'id' => 2,
                'cat_id' => 1,
                'name' => array('Выбрать рюкзак, какой? Помощь в выборе рюкзака или как унести с собой «всё»'),
                'anons' => array('<p>Рюкзак – заклятый друг и верный спутник любого туриста, охотника или рыбака. Сколько километрочасов он едет верхом на спине своего владельца! Рюкзак вмещает в себя весь «жит и быт» путешественника, обеспечивает его комфорт, но может и превратить поход в пытку. Чтобы этого не случилось, надо освоить искусство выбора рюкзака и мастерство его сбора. Но если последнее достигается в основном практикой, то к покупке «спиногрыза» можно и нужно подготовиться теоретически. Об этом сейчас и пойдет речь.</p>'),
                'text' => array('<p>Основной критерий различия рюкзаков – их размер, а точнее объём, измеряющийся, как ни странно, в литрах, что является неисчерпаемой темой для туристских шуток. Городской рюкзачок, а также заплечные мешочки альпинистов или велосипедистов – 18–30 литров. Средние рюкзаки – от 30 до 55 литров, предназначены для выездов на природу и небольших походов на один–два дня. Для серьёзных путешествий, когда рюкзак должен вместить как минимум спальник, палатку, запас еды и одежды, подходят мешки от 60 до 100 литров. Свыше 100 – это уже экспедиционные баулы или мешки для переноски байдарок.<br /><br />Крайности в размерах одинаково чреваты. Чтобы вместить все нужные вещи в маленький рюкзак, надо уметь их утрамбовывать, и всё равно многие оставшиеся «за бортом» предметы придётся навешивать снаружи (хотя некоторые туристы считают рюкзак символом бесконечности). Слишком большой рюкзак набьётся совершенно ненужными вещами, отравит своим весом поход и наградит радикулитом. Оптимальный размер туристского рюкзака: 80–90 литров – для мужчин, 60–70 – для женщин.<br /><br /><strong>Выбираем</strong><br />Как правильно выбрать рюкзак в магазине? Какие вообще бывают рюкзаки?<br />Однажды, накануне 23 февраля, довелось наблюдать попытки женщины, явно далёкой от туризма и охоты, приобрести в подарок рюкзак и потуги продавца, тоже, видимо, мало знакомого с туризмом, ей помочь. Стало, искренне, жаль, того, кому подарок предназначался. Но на самом деле всё просто. Всё многообразие моделей рюкзаков сводится к трём основным типам.<br /><strong>Станковые.</strong> У них есть прямоугольная жёсткая металлическая или пластиковая рама (станок), к которой с помощью люверсов и шплинтов крепится мешок. Раньше станковые рюкзаки делались на оборонных заводах, сейчас практически не производятся. Рамы в основном либо хлипкие, либо неподъёмные.<br /><strong>Мягкие.</strong> Так называют рюкзаки, которые не имеют никаких жестких элементов каркаса. По объему это могут быть как очень большие, так и совсем маленькие рюкзаки. Основные плюсы такой конструкции - минимальный вес, возможность компактно свернуть пустой мешок и убрать, например, в байдарку или каяк. Для придания жесткости рюкзак этого типа надо правильно уложить, а это целая наука. Один из вариантов - внутрь укладывают пенополиэтиленовый коврик: либо жесткий лист вдоль спины, либо сворачивают длинный коврик по всей окружности рюкзака.<br />Правильно уложенный мягкий рюкзак ни в чем не уступает более продвинутым каркасным моделям. На Аляске проводятся ежегодные соревнования рэйнджеров, один из этапов - переноска максимального груза на определенное расстояние. Рюкзак при этом самый простой, такой же, как был у героев Джека Лондона. Так вот, участники соревнований переносят по горной тропе почти 100 кг!<br />Не смотря на простоту таких моделей, по-прежнему популярность в среде охотников и рыболовов пользуются заслуженные ветераны – «Охотник», «Контур», «Динго» и «Медведь» от NOVA TOUR.<br /><strong>Каркасные</strong>. В принципе, все современные рюкзаки свыше 50 литров относятся к этому типу. Они имеют в себе латы жёсткости, специальные дюралевые пластины (каркас), которые делают спину рюкзака жёсткой и позволяют носить груз без вреда для позвоночника.<br />Большинство рюкзаков такого типа имеют «плавающую» подвеску (подвеска – это то, чем вещмешок крепится к человеку: лямки, пояс, спинные и поясничные опоры), когда точка присоединения лямок к рюкзаку перемещается по вертикали, регулируясь под рост владельца, что делает рюкзак более универсальным. Как, например, модели - «Тибет», «Юкон» и «Абакан» ТМ «NOVA TOUR». Длина лямок также должна регулироваться. На уровне груди к лямкам часто пришивается стяжка, чтобы они не соскакивали с плеч. Но на рюкзаке с хорошо подобранной подвеской грудная стяжка не нужна. Лямки не должны быть ни узкими, ни чересчур широкими. Для среднего человека оптимальна ширина 6–7 см. Набивка их должна быть мягкой, в то же время лямки не должны сминаться. Для набивки обычно используются различные вспененные пластики. Материал на краях лямок не должен ползти и разлохмачиваться.<br />Необходимая деталь любого современного рюкзака – пояс. Он позволяет перенести более половины веса на бёдра, разгружая позвоночник и плечи. Кроме того, пояс фиксирует рюкзак на спине, не давая ему болтаться из стороны в сторону. Он должен быть достаточно широким (сантиметров десять) и, как и лямки, мягким, но держащим форму и не сминающимся. Застёгнутый и отрегулированный пояс должен опускаться на бёдра и заклиниваться.<br />Также при покупке не стоит пренебрегать такими полезными мелочами, как наличие верхнего клапана с наружным и внутренним карманами, а также нижнего входа, отделённого от основного объёма рюкзака. Этот вход иногда называется «мышиной норой» и он имеет свой вход с фронтальной стороны рюкзака, что позволяет достать снизу спальник, не вытаскивая всю остальную поклажу. Убедиться в практичности подобных моделей можно также на примере рюкзаков NOVA TOUR.<br />Стоит обратить внимание на наличие различных приспособлений для крепления груза (альпинистского снаряжения, верёвок, удочек, коврика, палатки, сохнущих носков и другого необходимого снаряжения) снаружи, это всевозможные ремешки и лямки.<br />Ткань рюкзака должна быть прочной, износостойкой и непромокаемой. Самые распространённые из рюкзачных материалов Cordura и Oxford. Отличие их состоит в том, что Oxford мягче и легче, чем Cordura, но последний позволяет сохранять форму при неполном наполнении или вообще, когда рюкзак пустой, а также этот материал прочнее и дольше не промокает. Кстати, какой бы ни была ткань, сильный ливень всё равно промочит и вещмешок, и всё его содержимое, поэтому в комплекте предпочтительней иметь и защитный гермочехол.<br />При покупке рюкзака надо обязательно проверить, как он «сидит». Настраивать рюкзак нужно загруженным, только так можно оценить его «поведение» на спине. Надев рюкзак, застёгиваете и подгоняете пояс. Затягивать пояс надо достаточно плотно, чтобы он держал груз, но не мешал дышать и двигаться. Затем подтягиваете лямки так, чтобы вес груза распределился между лямками и поясом более или менее равномерно. Точка крепления лямок к рюкзаку должна при этом оказаться примерно на уровне середины лопаток или чуть выше. Если это место оказалось заметно выше или ниже, необходимо переставить плавающую подвеску или подобрать другой рюкзак по росту. В последнюю очередь подтягиваете верхние плечевые оттяжки до положения, при котором не ощущаются колебания рюкзака вперёд и назад.<br /><br /><strong>Области применения</strong><br /><br /><strong>Экспедиционные рюкзаки.</strong><br /><br />Так принято называть рюкзаки объемом свыше 80 литров, предназначенные для длительных путешествий и самого жесткого использования. Практически все, что было сказано о конструкции рюкзака, имеет свое воплощение в экспедиционных моделях NOVA TOUR.Если вы собираетесь совершать пешие или лыжные многодневные походы в горах, носить большой груз - вам понадобится такой рюкзак.<br /><br /><strong>Штурмовые рюкзаки.</strong><br /><br />Объем штурмового рюкзака - от 30 до 80 литров. Не обязательно идти с ним на штурм заснеженных вершин - под эту категорию попадают и рюкзаки для двух-трех дневных выездов за город. Современный штурмовой рюкзак - это как бы уменьшенная копия экспедиционного. Он легче экспедиционного, обычно менее 1,5 кг.<br /><br /><strong>Городские рюкзаки.</strong><br /><br />Спортивный стиль в моде. Поэтому столь популярны городские рюкзаки для повседневного использования. Кроме того, это просто удобно. Объем городского рюкзака колеблется в пределах от 10 до 30 литров. Что касается конструкции и внешнего вида, то тут есть где разгуляться дизайнерам! Впрочем, чаще всего все-таки на первый план выходит функциональность. Забавно, но габариты городского рюкзака в первую очередь определяются размерами ... стандартного машинописного листа формата А4. Предполагается, что документы в папке должны влезать в рюкзак, не сминаясь. Если влезет стопка бумаги, то скорее всего влезет и ноутбук, пара бутербродов, бутылка минералки, спортивная форма для вечерней тренировки и книжка для прочтения в метро по пути домой. Больше ничего от такого рюкзак и не требуется.<br />Итак, надеемся, небольшой ликбез поможет Вам сориентироваться в изобилии рюкзачной продукции. Удачных Вам путешествий!</p>'),
                'images' => array(
                    '284_vybrat-ryukzak-kakoy-pomo.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/vybrat-ryukzak-kakoy-pomosch-v-vybore-ryukzaka-ili',
            ),
            array(
                'id' => 1,
                'cat_id' => 1,
                'name' => array('Рюкзак «Тактика»', 'Backpack "Tactics"'),
                'anons' => array('<p>Рюкзак будет интересен, прежде всего, охотникам, любителям «МИЛИТАРИ» , страйклобистам итд.. На фронтальной стороне имеется стропы для дополнительной навески оборудования, внизу петли для крепления.</p>',
                    '<p>The backpack will be interesting, first of all, to hunters, fans of "MILITARY", strayklobist etc. On the frontal party is available slings for an additional hinge plate of the equipment, in the bottom of a loop for fastening.</p>'),
                'text' => array('<p>На лицевой стороне есть три отделения разных размеров:</p>
<div>
<p><img src="http://www.diafan.ru/userfiles/demo/article9.jpg" alt="" height="332" width="500" /></p>
<p>Центральное, самое маленькое для навигатора, рации или телефона.</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article12.jpg" alt="" height="332" width="500" /></p>
<p>Нижнее, самое большое, без проблем влезает от дождя или термобелье.</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article7.jpg" alt="" height="332" width="500" /></p>
<p>А за самым верхним скрывается органайзер:</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article5.jpg" alt="" height="332" width="500" /></p>
<p>Карабин для ключей, большое отделение для документов, прозрачный кармашек для всяких мелочей.</p>
<p>Причем оно очень большое, туда без проблем поместился литровый термос, с запасом!</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article2.jpg" alt="" height="332" width="500" /></p>
<p>Основных отделений два. Самое большое раскрывается очень глубоко, так что, достать или положить туда можно все, что вздумается без проблем</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article11.jpg" alt="" height="332" width="500" /><span><br>
Второе раскрывается не полностью, в глубину почти 70 см.</span></p>
<p>Можно использовать для любого длинномерного груза, например: , удочки, штатив, гидратор итд...</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article8.jpg" alt="" height="753" width="500" /></p>
<p>Два больших боковых кармана из сетки вместят то, что не вместилось внутрь рюкзака.</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article5.jpg" alt="" height="332" width="500" /></p>
<p>Понравились закрепки на 360 градусов в местах максимальной нагрузки. Это не просто закрепка, она работает на разрыв во всех направлениях, очень надежно!</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article6.jpg" alt="" height="332" width="500" /></p>
<p>Благодаря регулировке лямок и пояса по углу наклона, рюкзак можно подогнать на любой силуэт, все выглядит очень добротно и надежно, швы не растягиваются.</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article1.jpg" alt="" height="332" width="500" /></p>
<p></p>
<p><img src="http://www.diafan.ru/userfiles/demo/article4.jpg" alt="" height="332" width="500" /></p>
<p>Отличное решение- кармашки на поясе, для телефона, навигатора или рации&hellip;для всего, что должно быть под рукой!</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article10.jpg" alt="" height="332" width="500" /></p>
<p>Фурнитура выглядит очень внушительно! Особенно на местах нагрузки.</p>
<p><img src="http://www.diafan.ru/userfiles/demo/article3.jpg" alt="" height="332" width="500" /></p>
</div>',
                    '<p>On the face there are three offices of the different sizes:</p>
                    <div>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article9.jpg" alt="" height="332" width="500" /></p>
                    <p>Central, the small for the navigator, a handheld transceiver or phone.<img src="http://www.diafan.ru/userfiles/demo/article12.jpg" alt="" height="332" width="500" /></p>
                    <p>Bottom, the biggest, without problems gets from a rain or thermolinen.</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article7.jpg" alt="" height="332" width="500" /></p>
                    <p>And the organizer is behind the most top:</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article5.jpg" alt="" height="332" width="500" /></p>
                    <p>Carbine for keys, big office for documents, a transparent pocket for any trifles.</p>
                    <p>And it very big, there without problems the liter thermos, with a stock was located!</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article2.jpg" alt="" height="332" width="500" /></p>
                    <p>Main offices two. The biggest reveals very deeply so, it is possible to get or put there everything that will take in head without problems</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article11.jpg" alt="" height="332" width="500" /></p>
                    <p>The second reveals not completely, in depth nearly 70 cm.</p>
                    <p>It is possible to use for any lengthy freight, for example: rods, support, hydrator etc...</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article8.jpg" alt="" height="753" width="500" /></p>
                    <p>Two big side pockets from a grid will contain that didn\'t hold in a backpack.</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article5.jpg" alt="" height="332" width="500" /></p>
                    <p>Clips on 360 degrees in places of the maximum loading were pleasant. It not simply a clip, it works for a gap in all directions, very reliably!</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article6.jpg" alt="" height="332" width="500" /></p>
                    <p>Thanks to adjustment of straps and belts on a tilt angle, the backpack can be adjusted on any silhouette, everything looks very soundly and reliably, seams don\'t stretch.</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article1.jpg" alt="" height="332" width="500" /></p>
                    <p></p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article4.jpg" alt="" height="332" width="500" /></p>
                    <p>The excellent decision - pockets on a belt, for phone, the navigator or a handheld transceiver &hellip; for everything that has to be near at hand!</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article10.jpg" alt="" height="332" width="500" /></p>
                    <p>The accessories look very impressively! Especially on loading places.</p>
                    <p><img src="http://www.diafan.ru/userfiles/demo/article3.jpg" alt="" height="332" width="500" /></p>
                    </div>'),
                'images' => array(
                    '240_ryukzak-taktika.jpg'
                ),
                'rewrite' => 'clauses/pomosch-v-vybore/ryukzak-taktika',
            ),
            array(
                'id' => 12,
                'cat_id' => 2,
                'name' => array('До неба рукой подать…'),
                'anons' => array('<p>Вот и завершилась очередная экспедиция Клуба 7 вершин на Эверест. Еще раз поздравляем всех участников, а в их числе и известного в туристских кругах альпиниста Максима Богатырева!</p>'),
                'text' => array('<p>Именно благодаря ему, NOVA TOUR уже несколько лет путешествует по свету, а теперь еще и побывал на вершине высочайшей горы мира. О том, как проходила экспедиция на Эверест, рассказ из первых уст. О восхождении на высшую точку планеты Эверест, рассказывает давний друг NOVA TOUR Максим Богатырев:<br /><br />«Начну издалека – о том, как шла подготовка, а чтобы было понятней немного предыстории. Есть такие люди – «шерпы». Шерпы (наши помощники) – маленькие (около 160 см ростом) и юркие. Они живут (даже дети (!) в высокогорных селениях, редко спускаясь ниже 4000 метров над уровнем моря (вот это акклиматизация(!). Эти ребята могут сутками колотить кувалдой камни и лед, чего о нас, увы, не скажешь.<br /><br />В Непале уже давно существует своеобразный «кооператив» шерпов. Уже много лет они провешивают перильными веревками и лестницами ледопад Кхумбу. Конечно же, делают это не бесплатно. Каждая экспедиция платит «дань». И продолжить путь наверх альпинистский люд только после завершения всех подготовительных работ шерпами. Обычно это случается не раньше 15 апреля. Сидишь, ждешь, а погода аж звенит! И обидно до скрипа в зубах. Но ничего не поделаешь - на ледопаде трещины такие, что 20-этажные дома помещаются туда абсолютно свободно.<br /><br />Все это я к чему рассказываю, а к тому, что все экспедиции (и наша в том числе) начали заносить верхние лагеря после 15 апреля.<br /><br />Теперь кратенько о лагерях. Стандартно с этой стороны (со стороны Непала) Эвереста ставят 4 лагеря.<br /><br />Базовый лагерь раскинут по морене внизу ледника Кхумбу на высоте 5300-5400 метров над уровнем моря.<br /><br />Лагерь №1 на высоте 6100 - он стоит сразу за ледопадом. Шерпы по провешенному ледопаду до лагеря пробегают примерно за 3 часа. Но в среднем на его преодоление нужно 5-6 часов. Это тяжелая и опасная работа. Ледопад часто рушится. Поэтому уставшие альпинисты просто падают в лагере №1 на отдых. Дальше идти нужно по рваному леднику. Справа расположена красивейшая гора Нупзе, слева - Эверест. Долину замыкает гора Лхотзе. Получается такой снежно-ледовый котел. Когда солнце светит - внутри него свариться можно. Эта жара - вторая причина, почему ставят лагерь №1.<br /><br />Лагерь №2 на высоте 6400 метров. До него от лагеря №1 идти от 2 до 3 часов. И, в принципе, можно было бы пройти от базового лагеря до лагеря №2 за один прием, если бы не указанные выше две серьезные причины.<br /><br /></p>'),
                'images' => array(
                    '305_do-neba-rukoy-podat.jpg'
                ),
                'rewrite' => 'clauses/o-pokhodakh/do-neba-rukoy-podat',
            ),
            array(
                'id' => 11,
                'cat_id' => 2,
                'name' => array('Испытано на себе...'),
                'anons' => array('<p>1. Максим, слышал, Вы уже давно пользуетесь снаряжением NOVA TOUR и даже на Эверест брали брюки «Лес». Не замерзли? ;))</p>'),
                'text' => array('<p>Да, это действительно так. К примеру, Рюкзак «Каньон 60» уже несколько лет путешествует со мной по всему свету. Побывал он и на Эвересте. Брал с собой и Костюм «Лес». Отметил его плюсы и минусы - в куртке, как мне показалось, коротковаты рукава, а вот брюки мне очень понравились. Туристы иногда называют такие виды одежды «шуршунчики» или штормовой костюм. «Шуршунчик» - потому, что шуршит ;)) Еще не так давно такой материал в буквальном смысле добывали из парашютов или срезая навесы в кафешках на море ;)) шили штормовую одежду сами. Особенность такого материала и, соответственно, одежды - хорошая защита от ветра, легкость и быстрота высыхания. Все это есть в модели «Лес». А под «Лес» я поддевал брюки NOVA TOUR из флиса Брюки «Камчатка». Вот и не замерз ;)) Ветер не пропускала ткань брюк Лес, а тепло давала ткань брюк Камчатка. Конечно, я использовал этот комплект до определенной высоты на Эвересте. Но скажу абсолютно честно, что отработали они до высоты 6500 над уровнем моря. Можно было бы носить их и выше, то там все же необходима уже более специализированная одежда.<br />Ну и в заключение скажу, что на подходах к базовому лагерю, а это высота 5400, я использовал брюки опять же NOVA TOUR - Брюки «Лайт». Очень удобные и легкие брюки для теплой погоды.<br /><br />2. Посоветуйте, что из снаряжения NOVA TOUR может пригодиться на Эльбрусе. Планируем отправиться туда в августе.<br /><br />К любому путешествию нужно подходить серьезно. На мой взгляд, на Эльбрус просто необходимо взять снаряжение по следующему списку:<br />Одежда и обувь:<br />- куртка и штаны из мембранной ткани, например, куртка 3 в 1 «Эксель» (в ней сочетается и мембранная ткань и утеплитель из флиса) или куртка «Спирит». Ну и брюки самосбросы «К2». Или можно заменить этот набор удобным костюмом Бриз;<br />- пуховой жилет (или пуховка) - «Орис»- (отличный пуховой жилет!);<br />- флисовые куртка – 2 шт. и штаны – 1 шт. Например, куртка и брюки «Камчатка». Или куртка «Иркут» и брюки «Онега»;<br />- очень рекомендую взять с собой термобелье. Кстати, уже в грядущем зимнем сезоне NOVA TOUR выпускает коллекцию термобелья;<br />- ботинки пластиковые или хорошие трекинговые, «подкошечные», Я считаю, что вполне подойдет модель «Экстрим». Но если вы планируете серьезно заниматься альпинизмом, то вам все-таки надо будет купить и пластиковую обувь;<br />- гамаши;<br />- достаточное кол-во носков;<br />- перчатки теплые, рукавицы, рукавицы «верхонки» - можно одеть поверх перчаток или рукавиц;<br />- шапочка, «балаклава» или маска - от ветра и мороза.</p>'),
                'images' => array(
                    '304_ispytano-na-sebe.jpg'
                ),
                'rewrite' => 'clauses/o-pokhodakh/ispytano-na-sebe',
            ),
            array(
                'id' => 10,
                'cat_id' => 2,
                'name' => array('Записки путешественника'),
                'anons' => array('<p>Тест-драйв «Палатка «Памир 3 М» ; «Спальный мешок «Тундра»; «Жилет «Онтарио» и Жилет «Утепленный»; «Пончо».</p>'),
                'text' => array('<p><strong>Район Ферганского хребта.</strong><br /><strong>Горный туризм. Категория - пятая. </strong><br /><strong>Протяжённость активной части похода 220 км.</strong><br /><strong>Продолжительность ходовых дней - 24.</strong><br />Список группы: Никоноров Алексей Геннадьевич, Фролов Максим Евгеньевич, Овчинников Иван Викторович, Радионова Ксения Владимировна, Ураков Семён Викторович.<br /><br />О ходе экспедиции рассказывает Максим Фролов:<br />В моих ощущениях туризм это, прежде всего, познание нового. Щекотание нервов неизвестностью. В начале занятий туризмом прохождение маршрута и любого препятствия это новые ощущения. Но наступает время, когда прохождение известного перевала уже не приносит полного удовлетворения, потому что точно знаешь, что сейчас прожумарив ещё какое-то количество верёвок ты попадёшь на перевал, затем мелкая сыпуха и через 15-20 минут будешь внизу. Не хватает острых ощущений, потому что точно знаешь, что пройдёшь. Ведь прошли же до тебя другие. Конечно, жизнь полна неожиданностей, но первопроход, это слово очаровывает своей тайной. Заставляет учащённо биться сердце. Не смотря на всю подготовку к походу, по топографическим картам и космическим снимкам, до конца прохождения перевала сохраняется интрига, насколько сложным будет спуск. А поход по новому району сохраняет интригу до конца.<br />Идея похода принадлежит Александру Пурикову. Ферганский хребет привлёк нас к себе полным отсутствием отчётов о нём и достаточной близостью от аэропорта находящегося в городе Ош. Близость аэропорта позволяет надеяться, что сведения, полученные в походе, будут востребованы.<br /><br />При подготовке маршрута широко использовались космические снимки и топографические карты. Это позволило Александру Пурикову составить схему района, которая являлась основным картографическим материалом на маршруте. По результатам походов нашей группы, группы Гладилина и данным полученным от украинских туристов составлена новая уточненная схема.<br />Ферганский хребет расположен юго-западней озера Иссык-Куль. Фактически это точка сопряжения внутреннего Тянь-Шаня и Алая. На восток от хребта уходит хр. Кокшалтау, на юго-запад Алай, на западе от хребта Ферганская долина, сев – восточней хр. Ат-баши. В районе три крупных реки Терек, Кулун, Каракульджа, который после слияния образуют Сырдарью. Отсутствие подъездов и близость пограничных зон сохранили этот район в нетронутом для туристов виде. В район могут попасть только группы готовые к длительному автономному существованию, потому, что в средних течениях этих рек находятся серьёзные каньоны, затрудняющие вход в долины рек. Десять лед назад в район оз. Кулун был объявлен заповедным.<br /><br />Нам очень хотелось попасть в район озера, но выяснить точно границы заповедника и возможность оформления пропуска в заповедник нам не удалось. <br /><br />Район туристами практически не посещается. Есть сведения о прохождении района группой Браткова в 1994 году, который прошёл пер. Арпа-Кулун 2Б*. Сравнивая его описание с сегодняшней ситуацией, можно сказать, что снежный покров сильно уменьшился. Ледники стали более разорванными. Сейчас в район стали осваивать туристы из Киевского клуба Глобус. Но размеры и нетронутость района позволяют ещё многие годы делать первопрохождения перевалов и вершин.<br />Маршрут был построен линейно и в достаточной удалённости от населённых пунктов, поэтому подбор экипировочного снаряжения проходил особенно тщательно, какие-либо эксперименты были недопустимы. Аналог палатки Палатка «Памир 3 М», «Байкал 3», турклубом «Вестра», был тестирован ранее, после чего был внесён ряд конструктивных предложений. Разработчики учли их и получился данный вариант. Следовательно, эта модель идеально подходила для нашего похода, оставалось лишь зафиксировать, на сколько точно сделаны все доработки и на сколько мы были правы.<br /><br /><strong>28. 07. 2011, понедельник.</strong><br />Ош- п.Терек<br />На вахтовке выезжаем из города.<br />В посёлке Терек магазин 2 недели не работает. Дорога переходит на другую сторону реки. Но мост внушает опасение шаферу, и он отказывается вести нас на противоположную сторону реки. Местные жители говорят, что иногда через мост проскакивают «Газы- 66», но, говорят, что шафёры решаются не всегда. Лошадей в посёлке практически нет. Все говорят, что все задействованы на сенокосе. В поселке большое количество УАЗов. Договариваемся с машиной, забрасываем все вещи до того места куда дойдет. Все остальные идут пешком. Машина проходит 9 км. Здесь находятся, развалины старого скотного двора. Участники подходят к рюкзакам уже в темноте. За водой приходятся спускаться довольно далеко. Не смотря на вечер, мимо лагеря часто проходят местные жители с лошадьми. На предложения поработать носильщиками практически все отказываются, ссылаются на сенокос и занятость. Пообещал только один, но спать легли с уверенностью, что завтра с утра придётся челночить. <br /> <br /><strong>29.07. 2011, вторник.</strong><br />С утра было счастье. Местные жители привели двух лошадей и ослов. Навьючиваем лошадей и осликов. Тропа чётко выраженная. Движение по тропе довольно активное, и в основном попутное. Люди едут на сенокос. На попутных участках они забирают у нас рюкзаки. Поэтому изредка по очереди мы остаёмся без рюкзаков. Проводники приглашают пить чай к себе в джайло. Поклажу сбросили у речки Балганды. Река ближе к вечеру становится грязной, не пригодной для питья. <br /><br /><strong>30. 07 2011, среда.</strong><br />N 40 27 14,0 EO 74 34 56,3<br />Река стала чистой и её опять можно использовать для приготовления пищи. Начинаем непростую и не приносящую радости работу – челночим рюкзаки и коробки с заброской вдоль Терека. Через переход тропа пропадает, хотя по карте ещё 5 км тропа должна быть. Временами кажется, что она идёт верхом, затем опять теряется в зарослях. После бесконечных разведок все ровно спускаемся к реке, и движемся вдоль неё, перелезая прижимы. Вечером встречаем егеря с лошадью. Егерь явно хочет денег, говоря о заповеднике. Но на наше счастье он по-русски не говорит. Руководитель (Никоноров А.Г.) делает вид, что не понимает и начинает показывать сопроводительное письмо от ТССР, погранпропуска, ходатайство фирмы, обеспечивающее трансферт и прочие бумажки. Дело заканчивается ужином, колбасой с ромом, (купленным в дьюти фри) т.к. все родники в это время уже совсем грязные.<br />На предложение сейчас переправится на другую сторону реки, егерь утверждает, что сейчас нельзя смоет вместе с лошадью. Интересный получается диалог, то мы понимаем друг дуга, то, когда касается пропуска в заповедник, не понимаем. Координаты ночёвки N 40 27 14,0 EO 74 34 56,3, высота 3749 метров.<br /><br /><strong>01.08. 2011, четверг.</strong><br />N 40 27 14,0 EO 74 34 56,3 – N 40 27 07,1 EO 74 37 54,5 Спускаясь к реке, видим несколько родников с чистой водой. Егерь долго выбирает место брода. В конце концов, решаемся на переправу выше левого притока (р.Тюсджайлау). Несмотря на раннее время, вода в реке доходит до крупа лошади и временами её подносит. Аттракцион «переправа на лошади» бодрит. Егерь с лошадью - наше счастье. С этой стороны реки нас уже ждут, здесь джайло. В этих нехоженых местах турист в диковинку. Нас последовательно приглашают сразу в несколько юрт, в одной чай, хлеб, масло, сметана, в другой кумыс, «творожно-солёные» шарики. В свою очередь мы балуем детей сладостями. С некоторой тяжестью (в животах) двигаемся дальше. Путь идёт орографическим левым берегом реки Тюсджайлау. С плавным набором высоты. Встаём перед границей ледника. Координаты ночёвки N 40 27 07,1 EO 74 37 54,5, высота 3662м..<br /><br /><strong>02.08. 2011, пятница.</strong><br />N 40 27 07,1 EO 74 37 54,5 – N 40 29 08,0 EO 74 36 57,8 <br />Перевал Италмас 2А, высота 4344м.<br />Двигаемся орографическим левым бортом ледника по морене. Через переход становится виден взлет на перевал. Около 200 метров льда крутизной 45 градусов. Точка выхода на ледник N 40 27 368 Е 74 36 034, высота 4094м .Траверсируем ледник влево (орографически вправо) и выходим на длинную пологую ледовую дорогу выводящую на гребень. Одеваем кошки, начинаем двигаться вверх. Ледник открытый 25 градусов, длинной около 500 метров. Последний участок крутизной 45 градусов длинной метров 20. Выходим на гребень. Складываем тур. На карте этот перевал обозначен как №73.
                    Право назвать перевал предоставляем ребятам из Ижевска. Они называют перевал «Италмас» N 40 26 833 Е 74 36 385, высота 4344 м. Категория сложности 2А.<br />Спуск представляет собой длинную, мелкую сыпуху крутизной 30 градусов с перепадом по высоте 500 метров. За 4 перехода по 30 минут были в нижней точке, откуда должен начаться подъём на следующий перевал. Координаты N 40 29 08,0 EO 74 36 57,8, высота 3999м. Хотели двигаться вверх, но пошёл обильный мокрый снег. <br />Встали на ночёвку.<br /><br /><strong>3.08. 2011, суббота.</strong><br />N 40 29 08,0 EO 74 36 57,8 – N 40 29 134 Е 74 36 936,<br />Перевал Намасте 3 А , высота 4293м<br />Начинаем движение вверх. Переходы увеличили до 40 минут. Подъём идёт по осыпи 20-25 градусов. Вчерашние осадки, которые заставили нас рано встать на самом деле позволили переночевать нам в самом оптимальном месте. Потому что выше нет нормальных мест для ночёвки. После первого перехода намечаем путь подъёма на перевал, обозначенный на карте как № 65. Весь склон это крутая мелкая сыпуха крутизной 30 градусов, подняться по которой крайне затруднительно, и только в правой части склона есть скалы, позволяющие зацепиться за рельеф. Решили выходить на гребень в районе выхода скал. Четыре перехода по 40 минут. Последний участок по простым разрушенным скалам крутизной 45 градусов. Право назвать перевал предоставлено представителю Смоленска. Макс предлагает назвать перевал «Намасте» (хинди). Так приветствуют и желают здравия индийцы. Идея такова, что когда следующая группа выходя на перевал читает записку и сама того не зная приветствует всех восходителей и сам перевал.<br /><br />Одеваем системы начинаем двигаться вниз на ледник. 80 метров перил вниз с большим отклонением вправо по ходу, чтобы обойти большой разрыв бергшрунда. Затем 240 метров вниз, крутизной 40-50 градусов. В нижней части спуска пересекаем бергшрунд. Впопыхах не сняли координаты перевала. Точка окончания перильных верёвок N 40 29 269 Е 74 37 293, высота 4293м. Дальнейшее движение в связках. Ледник закрытый. Есть трещины и довольно широкие. Приходится прыгать. Выходим на открытый ледник (N 40 28 860 Е 74 37 043 высота 3690), не отдыхая бежим вниз. Хочется встать не на льду. Спуск с языка ледника довольно крутой, градусов 30. Встаем у языка ледника. N 40 29 134 Е 74 36 936, высота 3 999 м. День получился довольно тяжелый. Практически 12 часов работы.<br /><br /><strong>04. 08. 2011, воскресенье.</strong><br />N 40 29 134 Е 74 36 936 – N 40 30 519 Е 74 34 462<br />Начинаем движение вниз к реке Терек. Местами видна тропа. Идём вдоль реки. Переходы по 40 минут. Точка выхода на реку N 4030 312 Е 74 36 815, высота 3404м. Дорога привела нас в каньон. Прижимы очень неприятны. Иногда приходится расчищать площадку, чтобы поставить ногу. Вышли к снежно-ледовому мосту через р.Терек. Мост чуть выше впадения в р. Терек реки Кашкасу. Координаты N 40 30 517 Е 74 34 459, высота 3174м. Встаём лагерем на ровной площадке над мостом. Предыдущий день и каньон нас здорово измотали.<br />По карте тропа доходит до этого места. Мне кажется, что раньше р.Терек была менее полноводной и тропа шла вдоль реки. Сейчас в связи с глобальным потеплением сильное таяние ледников и сильный разлив реки, поэтому такие прижимы и остатки троп от прижима к прижиму. Встаём. Хоть и рано, но у нас есть запас по времени. Два тяжёлых дня, необходимо отдохнуть. Внизу у моста выходы минеральных источников. Пьём. Моемся. Завтра надо сходить за заброской и отсортировать продукты. Приток справа (р. Кашкасу) очень полноводный, заброска с правого берега. Может быть, с утра сможем переправиться.<br /><br /><strong>05. 08. 2011, понедельник.</strong><br />Заброска.<br />Попытка найти брод через р. Кашкасу, закончилась ничем, хотя по карте тропа показана с этого берега р. Терек и вроде как надо переправляться. Переходим по снежному мосту на левый берег р. Терек. Здесь плохо просматривается тропа, то исчезает, то появляется. Через полкилометра ещё один снежный мост через р. Терек. Чувствуешь себя настоящим первопроходцем. Переходим по нему на правый берег. Сразу за мостом прижим. Большая часть дороги до заброски это прижимы. От простых до откровенно сложных и опасных. Идём без отдыха, потому что налегке. Где возможно организовываем гимнастическую страховку. Подошли к заброске с пониманием, что назад вдоль реки нам не пройти, так как мы пойдём гружёными, а вода в реке поднялась. Разбираем продукты. И начинаем подъём на склон практически от заброски. Набор по высоте довольно значительный метров 400. Но беда в том, что среди зарослей кустов на склоне тропы просто нет. Проламываемся через кусты. По времени это не меньше чем движение по прижимам. Наверное, даже более трудоемко. Но значительно безопасней. Проходим верхом последний прижим перед заброской, самый опасный. Спускаемся к реке по кулуару промытым ручьём.<br />Измотанные возвращаемся в лагерь. Полный рабочий день. <br /><br /><strong>06.08. 2011, вторник.</strong><br />Разведка<br />Завхоз сортирует продукты продукты, от которых мы решили отказаться. Количество продуктов значительно. Очень плохо идёт сахар. Иван, Макс и Семён ушли на разведку, с целью выяснить можно ли по нашему берегу дойти до поворота, ведущего на Хаокан. Заодно и занести часть вещей. Разведка показала, что прижимы есть, но проходимо.<br /><br /><strong>07. 08.2011, среда.</strong><br />N 40 30 519 Е 74 34 462 – N 40 32 28,4 EO 74 37 25,2 <br />Два перехода по 40 мин. и мы на притоке ведущем к Хаокану Аушукан. Начинаем двигаться вверх. Подъем идёт вдоль ручья Аушукан. Практически весь ручей закрыт лавинными выносами. Русло ручья это довольно узкий кулуар, практически равномерно поднимающийся с уклоном 20-25 градусов. Зимой и весной здесь лучше не ходить. Идём по сорок минут. Стараемся идти к краю кулуара, если возникает необходимость его пересечь, то делаем это быстро и под наблюдениям других участников. Три перехода и мы подходим к леднику. Ледник пологий градусов 10 -15. Встаём на ночёвку. Координаты ночёвки N 40 32 28,4 EO 74 37 25,2, высота 4180 м.<br /><br /><strong>8.08. 2011, четверг.</strong><br />N 40 32 28,4 EO 74 37 25,2 – N 40 32 474 Е 74 37 421<br />Перевал Удмуртия, 3А (первовохождение), 4630м. Вершина Хаокан Южный, 3А (первопрохождение), 4783м. Начинаем движение вверх по леднику. Через 40 минут на право отходит ледовый взлёт. Системы одеты ещё в лагере. Координаты начала взлёта N 40 32 393 Е 74 36 945, высота 4282 м. Взлёт 460 метров 45 градусов. Лед. Мы на перевале. Спуск на противоположную сторону осыпной. Но нам не туда. Нам на одну из высочайших вершин района г. Хаокан Южный. Перевал, на который мы поднялись первыми, ребята предложили назвать Удмуртия.(3А* – 4630м) Координаты N 40 32 341 Е 74 37 307.Пока готовим обед и складываем тур, Макс с Иваном вешают верёвку по гребню, в сторону Хаокана Ю. Начинаем двигаться в сторону вершины. Верёвки вешаются через вершины жандармов. Постоянно приходится то жумарить, то дюльферять. Проходим одну две верёвки и вдруг понимаем, что идёт гроза. Ледорубы зажужжали. Строем площадку под палатку. Через час группа продолжает строить площадку, а Иван с Максом продолжают вешать перила к вершине. Гроза подошла стороной. Скальный взлёт 60 градусов 80 метров, траверс гребня 30 градусов 60 метров. Траверс 40 метров. И взлёт 60 градусов 20метров. Группа на вершине Хаокан Южный – 4783м. Маршрут подъёма мы оцениваем как 3А. (первопроход). Спуск крутой снег 45 градусов, 80 метров. Ставим палатки на выположении, уже в темноте. Координаты ночёвки N 40 32 474 Е 74 37 421, высота 4769 м. Суммарно препятствие пер Удмуртия и подъём с него на гребень оценивается нами как 3а*<br /><br /><strong>09.08. 2011, пятница.</strong><br />N 40 32 474 Е 74 37 421 - N 40 33 470 Е 74 36 618,<br />Вершина Хаокан Северный 1Б, 4838м., перевал Олимпийский (п/п) 3А, 4690м. Траверс (первопроход) технической сложности не представляет. Двигаясь по хребту, пересекаем несколько понижений в хребте, которые могут быть использованы в качестве перевальных. Их координаты N 40 3228.8 Е 74 37 21.7, высота 4756 м. Вершина Хаокан Северный, высота 4838м. Координаты N 40 32 849 Е 74 37 482. Траверс 
                    мы оцениваем как 2а. Видим намеченный перевал и понимаем, что при некоторой расторопности можем пройти его сегодня. Вяжемся в связки. Спуск осуществляем по маршруту первовосхождения.<br />Первоначально первовосходители оценивали как 2А, а затем написали, что сложность 1Б. Мы склоняемся к оценке 2А. Спуск мы прошли не до конца, но тот участок, который был пройден, представляет довольно крутой гребень. Двигаться надо в связках.<br />Отдельные участки гребня на гране необходимости переменной страховки. Спустившись до уровня цирка, уходим влево под седловину намеченного перевала. Связка Максима и Ивана начинает обрабатывать склон, не дожидаясь подхода связки Никоноров, Семён, Ксения. Подъём 320 метров 45 градусов. Оцениваем перевал как 3А. Называем перевал Олимпийский, координаты N 40 33 11,9 EO 74 37 17,5, высота 4690м. Второй день идёт олимпиада. Начинается дождь. Обедаем. Начинаем спуск с перевала. Вначале спуска разрушенные скалы, затем осыпной склон 45 градусов. Верёвка 80 метров. Затем 300 метров по мелкой осыпи вниз. Замечаем что если будем двигаться строго вниз то выскочим на крутой ледник, покрытый камнями. Уйти направо мешает rрутой ледничёк, вешаем через него траверсную верёвку. И продолжаем спуск.<br />При последующих прохождениях сразу после завершения работ с верёвкой надо уходить вправо по ходу движения почти до скал. Начинается дождь. Сбросив километр высоты с перевала, встаём на ночёвку. Устали.<br />Координаты ночёвки N 40 33 470 Е 74 36 618, высота 4042м.<br /><br /><strong>10.08. 2011, суббота.</strong><br />N 40 33 470 Е 74 36 618 - N 40 35 665 Е 74 36 399,<br />Утром очень холодно. Солнце никак не выйдет из-за гор. Снимаем лагерь. Выходим на серединную морену и движемся в низ. Идём левым бортом ледника полтора перехода. Притоки, которые приходится преодолевать довольно полноводные. Встречаются прижимы. Выходим на место ночёвки, это место постоянного посещения местных жителей. Есть нарзан за скалой. У скального выхода камни сложены на манер молельни. В дальнем конце полянки останки козлов. Но в целом довольно чисто. Координаты N 40 35 665 Е 74 36 399, высота 3467м.<br /><br /><strong>11. 08. 2011, воскресенье.</strong><br />N 40 35 665 Е 74 36 399<br />Днёвка. Моемся. Ремонтируем снаряжение. Разведываем дорогу вдоль ледника. В левом кармане ледника, что-то в виде тропы. По леднику, как шёл Братков 17 лет назад, идти невозможно, ледник сплошной ледопад. Выносим часть вещей вверх на два перехода.<br /><br /><strong>12. 08. 2011, понедельник.</strong><br />N 40 35 665 Е 74 36 399 - N 40 33 441 Е 74 33970<br />Выходим в начале девятого. Дорога в кармане левого борта ледника хорошая. Прозрачный ручей. Сначала трава, затем песок. Идём своим темпом. Через два часа подъёма выходим на место стоянки охотников. Ровная, довольно просторная травянистая поляна, с чистым ручьём и великолепными видами на ледопад. N 40 35 915 Е 74 35 599 высота 3775м. Ещё один переход и мы подходим к месту, где необходимо выходить на ледопад. Косая ледовая полка пересекает ледопад по диагонали, и, похоже, выводит на выположение на следующей ступени ледника. Полочка с трещинами, но кажется, их можно либо обойти, либо перепрыгнуть. <br />Первая связка Макс и Иван начинают прохождение (разведку) ледника. Монстры совершают разведку с рюкзаками. Первая трещина проходится сверху достаточно сложно. Надо подняться не высоко метра на два, зигзагом обойти трещину, и спустится с другой стороны. Но сделать это надо по стенке крутизной 80 градусов, с рюкзаком и в достаточно узком коридоре ледовой перемычке. В верхней точке Макс заворачивает бур, конечно, страхующий в случае срыва удержит сорвавшегося, но вылезать из трещины ему придётся самому, подойти и оказать помощь ему будет сложно слишком маленький коридор. Очень сложный последний шаг перед выравниванием, кошку надо бить в склон с отрицательным уклоном. После дальнейшего просмотра Макс даёт команду двигаться. Все остальные трещины преодолеваются менее экстремально, но индивидуальную технику надо иметь. Приходится, и прыгать, и проходить маленькие кусочки на передних зубьях.<br /><br />Технические сложности оказывают на Макса и Ивана действие схожее с действием красной тряпки на быка. Ко времени нашего подъёма они уже сделали крюк по леднику и пришли к выводу, что следующую ступень лучше обходить с правого борта ледника по ходу (орографически с левого борта ледника). И уже работают по его прохождению. Движение не самое простое. На следующем выположении нас дожидаются ребята. Можно вставать здесь, можно попытаться подняться ещё метров на 50 -70 по вертикали, но тогда вставать придётся под склоном. На нём следы лавин. Решили вставать здесь. ( N 40 33 441 Е 74 33970 высота 4263м) На ужин берём воду из ручьев, а после ужина обнаруживаем, что вода замёрзла. Топим снег, чтобы утром пораньше выйти.<br /><br /><strong>13. 08. 2011, вторник.</strong><br />N 40 33 441 Е 74 33970 <br />В начале седьмого готовы выйти, но снизу идёт облачность, решили поставить палатки и подождать. Сыграли в высокогорный гольф. Погодные условия не улучшались, сначала просто туман, а затем пошёл снег. Спрятались в палатки. Снег начинает усиливаться. Через каждый час вылазам откапываться. Обстановка становится лавиноопасной. Мы стоим достаточно далеко от склона, но, кажется, что завра придётся пережидать. <br />При редком увеличении видимости видно, что со всех окружающих склонов идут лавины. Снег прекращается только в начале шестого. Снега выпало около 40 см. Вечером решаем, что завтра стоим. Вечером нам улыбается солнце. <br /><br /><strong>14. 08. 2011, среда.</strong><br />N 40 33 441 Е 74 33970 - N 40 32 493 Е 74 32 855<br />Перевал Арпа-Кулун 2Б* , 4738м.<br />Встаём в полшестого. Сказывается, что весь предыдущий день спали. Снег существенно осел. Ещё сидеть один день очень не хочется. Решаем снять лагерь подойти до места выхода на хребет. А затем по месту принять решение подниматься на хребет, или возвращаться и ставить лагерь. Подходим к взлёту на хребет. Снег довольно плотно утрамбован ветром к склону, снежных досок нет. Взлет крутизной 45 градусов. Около двух верёвок по 80 метров. Движение облегчает снег, на котором легко формируются ступени. В 9 часов мы на гребне. Спуск с него приводит, в какой-то не мыслимый ледопад. Мы движемся по гребню в связках, по пути, пройденному Братковым 17 лет назад. Взлет достаточно крутой. Места крутизной до 50 градусов сменяются выполажением до 25 градусов, затем опять круто. Выходим на перевал 2Б*, N 40 32 825 Е 74 33 464, высота 4738м. Оставляем рюкзаки. Восходим на ближайшую вершину. Снимаем записку оставленную Киевлянами за 4 дня до нас. Как оценивать наше достижение даже не знаю. Вершина не названа. Описаний нет, но на ней стоит триангуляционный пункт. Украинцы взошли на вершину с противоположного хребта, и они оценили восхождение как 2А. Очевидно, геодезисты шли по пути Киевлян. Восхождение с нашей стороны ближе к 2Б. Координаты вершины 4743 N 40 32 864 Е 74 33 463.<br />Возвращаемся к рюкзакам. Надёжно закрепить верёвку в начале кулуара не удаётся. Крепим на скалах правее. Спуск осуществляем со значительным траверсом вправо, а затем вниз по кулуару. Проблемы последнего, разложить верёвку так чтобы сдёрнуть её и не засыпать себя камнями. Начинается дождь. Две других верёвки строго вниз без проблем. (верёвки 80 метров). Последняя верёвка в нижней части не очень актуальна. Но перевал оцениваем как 2Б*. Окончание верёвки N 4032 792 Е 74 33 336, высота 4564м. Далее спускаемся по сыпухе, уходя траверсом вправо по ходу. К моменту выхода в нижнюю точку видим кулуар, ведущий в наше направление подъёма. Встаём на ночёвку. Место бивака встречает нас улучшением погоды. Воду на завтрак набрать не удалось. Топим снег. N 40 32 493 Е 74 32 855 высота 4254м. Завтра пер N54<br /><br /><strong>15.08. 2011, четверг.</strong><br />N 40 32 493 Е 74 32 855 - N 40 34 265 Е 74 33 420 <br />Перевал Александра, 3а, 4507м.<br />
                    Начинаем двигаться по кулуару в сторону перевала. Кулуар осыпной, крутизной 25 градусов, заканчивается не доходя до гребня. Понимаем, что картографический материал не очень точен, путь на наш перевал траверсом вправо по ходу. Группа на перевале N 40 32 858 Е 74 32 804 высота 4507м. Очень ветрено. Складываем тур. Прошу у ребят согласие на название перевала, на который взошли именем Александра. Обвязываемся. Спуск с нижней точки простреливается камнями. Уходим немного вправо. Бросаем верёвку Спуск ледовый, крутизной от 60 до 75 градусов. Практически стена. 160 метров. Внизу большой бергшрунд. Разрывы в точке его преодоления более 2х метров по высоте, по ширине меньше метра. Во всех остальных местах он шире и больше по высоте. Пока сложность в районе 2Б, но не понятно, что дальше. Впереди еще три или четыре ступени ледопада. Начинаем движение в связках по леднику. В начале по центру ледника. Затем всё более и более отклоняясь влево. Обход разрывов, приводит нас к левому борту ледника. Крепим верёвку в орографически левой части ледника почти в ранклуфте. Надеемся, что с её помощью обойдём верхний ледопад. Понижение в левой части позволяет обойти верхний ледопад. В этом месте начинается подъём заявленный нами перевал N75. Но это крутой ледник с лежащими на нём камнями. Двигаться вверх сумасшествие. Нам кажется, что надо уйти вправо и там по сыпухе обойти следующую ступень ледопада. Но уйти вправо у нас не получается, дорогу преграждают большое количество широких трещин. Не разорванных участков на леднике просто нет, Постоянно приходится организовывать страховку, прыгать. Спускаться на один два метра вниз на передних зубьях. Дорогу вправо преграждают трещины такого размера, что двигаться в том направлении просто не возможно. Мы опять попадаем в левую часть ледопада и опять крепим верёвку вниз. Опять работа с индивидуальной техникой передвижения по льду. В итоге прошли и вторую ступень. Высокий ледовый мост позволяет нам попасть на среднюю более ровную часть ледника Впереди нас более ровные площадки ледника разделённые зонами трещин от одного борта до другого. Спешить дальше из-за сохранности ледовых и снежных мостов бессмысленно, всё что могло растаяло или ослабло. Садимся обедать. Чай, сухари, сало и абсолютное спокойствие. Ясно, что совершенно непонятно как выйти на морену, но если дошли сюда, то выйдем. За тридцать лет&amp;am</p>'),
                'images' => array(
                    '297_zapiski-puteshestvennika.jpg',
                    '298_zapiski-puteshestvennika.jpg',
                    '299_zapiski-puteshestvennika.jpg',
                    '300_zapiski-puteshestvennika.jpg',
                    '301_zapiski-puteshestvennika.jpg',
                    '302_zapiski-puteshestvennika.jpg',
                    '303_zapiski-puteshestvennika.jpg',
                ),
                'rewrite' => 'clauses/o-pokhodakh/zapiski-puteshestvennika',
            ),
            array(
                'id' => 9,
                'cat_id' => 2,
                'name' => array('По дороге к «Горе счастья»'),
                'anons' => array('<p>Давно это было - много лет назад. Но свой первый в жизни день в горах помню до мельчайших подробностей.</p>'),
                'text' => array('<p>Помню и слова инструктора – ныне доброго друга и надежного спутника многих путешествий Максима Богатырева: «В горах человек учится заново дышать, ходить и совершенно по-иному воспринимает окружающий мир!». С тех пор пройдено немало дорог, но каждый раз, оказываясь в окружении величественных гор, убеждаюсь: самое красивое и, казалось бы, невероятное, природа прячет от нас в этих труднодоступных местах. Чтобы, пройдя все преграды и совершив главную победу – победу над самим собой, человек мог с восторгом созерцать доступную в этот миг только ему красоту.<br />В один из таких моментов и родилась в моей душе мечта – побывать на вершине (своего рода Мекке туристов) знаменитого Эльбруса. Ведь не даром же с адыгейского языка Ошхамахо (одно из многочисленных названий этой горы) переводится как «Гора счастья»...<br /><br />Справка:Эльбрус – двувершинный конус вулкана. Западная вершина имеет высоту 5642 м, Восточная – 5621 м. Они разделены седловиной – 5200 м и отстоят друг от друга примерно на 3 км. Последнее извержение датируется 50 г.н. э. &plusmn; 50 лет. По альпинистской классификации Эльбрус оценивается как 2А снежно-ледовая, прохождение обеих вершин – 2Б. Есть и другие, более сложные маршруты, например Эльбрус (З) по С-З ребру 3А.<br /><br /><strong>Другие названия:</strong><br />Минги-Тау – вечная гора (карачаево-балкарское).<br />Ельбурус – направляющий ветра (ногайское).<br />Асхартау – снежная гора асов (кумыкское).<br />Джин-падишах – царь горных духов (тюркское).<br />Альбар (Альборс) – высокий; высокая гора (иранское).<br />Ялбуз – грива снега (грузинское).<br />Ошхамахо – гора счастья (адыгейское).<br />Урюшглюмос – гора дня.<br />Кускамафь – гора, приносящая счастье.<br /><br />Как говорят мудрые люди: «Если есть желание – появляются возможности!». И ведь, не поверите, ОНИ эти самые возможности появились!!!<br />Возможность Первая совершенно неожиданно возникла в марте 2011 года в лице давних партнеров – Компании «Белый Медведь». Именно они стали инициаторами проведения совместной с NOVA TOUR экспедиции по Приэльбрусью с восхождением на высшую точку самого Эльбруса.<br /><br />Возможность Вторая, уже в лице руководства Компании «НОВА ТУР», пошла навстречу Первой. Так было положено начало подготовки к летней экспедиции. А спустя четыре месяца (выслушав массу советов и рекомендаций, подкрепившись опытом «бывалых», статьями сайтов и пересудами форумов) – мы уже покидаем Москву. Наш путь лежит на юг в сторону Кавказских гор.<br /><br />Первая высота! Знакомство с Приэльбрусьем начинаем с хорошо известной любителям горных лыж горы Чегет. 3650 метров над уровнем моря. Летом здесь тоже есть на что посмотреть. Даже Эльбрус подмигнул нам из-за тучек ;)) И это наша первая высота!<br /><br />Уже «кырдык»? Нет, это только Кыртык! Второй день экспедиции вспоминаю с особым «теплом», я бы даже сказала «жаром». Палящее солнце на фоне бесконечно змеящейся вверх вдоль ущелья реки Кыртык дороги (очень созвучно с «кырдык» и вполне совпадает с моими ощущениями ;)). Пластиковые ботинки, обутые специально для тренировки, кажутся неподъемными, каждый шаг - как последний. Наверное, именно так чувствовали себя закованные в кандалы каторжники. Сжалившиеся надо мной спутники, предлагают сменить обувь на кроссовки (Спасибо, Александр, огромное!). И это только начало длинного дня. Предстояло еще успеть побывать в долине Адырсу, а затем из Верхнего Баксана, через поселок Эльбрус добраться до альплагеря Джантуган.<br /><br />На ночевку становимся палаточным лагерем в приюте «Очаг» и он становится нашим домом на ближайшие несколько дней. Отсюда ребята выходят на скальные и ледовые тренировки. Отсюда же отправляемся в сторону перевала Койавганауш. И это уже особая история.<br /><br />Справка:Перевал Койавганауш (1А категория сложности, 3500 метров над уровнем моря). Расположен в хребте Адылсу между вершинами Койавганбаши и ВИАтау. Ведет с ледника Джанкуат (река Адылсу) на ледник Койавганауш (река Адырсу).<br /><br />«Заруба-а-а-йтесь!» Это слово стало крылатым в нашей группе уже по возвращении с перевала. А чтобы читателю было понятней немного предыстории.<br /><br />Группа единомышленников, стремящихся покорить Эльбрус сложилась неожиданно и, не смотря на общую цель, физическая подготовка и опыт горных походов был совершенно разным. Кто-то и вовсе оказался в горах впервые. Соответственно, и выпавшие на наши плечи испытания переживали по-разному. Для меня лично, Койавганауш оказался «крут» в прямом смысле этого слова. А то, что опыт обращения с ледорубом и умение зарубаться, в случае падения, просто необходим прочувствовали многие. Даже уже на самом перевале, при встрече с рогатыми обитателями гор, в их блеянии слышалось: «Заруба-а-а-йтесь!!!». И надо сказать, мы последовали совету «местных жителей» - на приюте «11» под руководством нашего гида добросовестно отрабатывая срывы и падения на учебном склоне. Но это было чуть позднее. А пока нам предстояло еще несколько дней акклиматизации и знакомство с еще одним перевалом 1А категории - Солдатским...<br /><br />Справка:Перевал Солдатский (1А категории сложности, 3383 метров над уровнем моря) . Расположен в отроге горы Сарыколбаши-Терсак (3776 м), в юго-восточном отроге Эльбруса. Соединяет долины Терскол и Иткол (притоки Баксана). Ведет из верховьев ручья Сарыкол в цирк Суаккалар (Суакколар). Самостоятельного значения не имеет, но в связке с перевалом Суаккалар ведет в долину Ирик.<br /><br />После ледово-каменистого Койавганауша, Солдатский перевал с его буйно растущими травами, кажется просто раем. И где-то совсем рядом Эльбрус. До нашей встречи с ним остается лишь пара дней.<br /><br />Вперед и вверх!!! И вот он долгожданный день наступил. Три очереди подъемников доставляют нас к точке отчета - на станцию Карабаши (3750 метров над уровнем моря). Далее путь к приюту «11» (4100 метров над уровнем моря), который и станет местом старта предстоящего восхождения. Уже здесь ощущается недостаточность кислорода. Дышать хочется чаще и глубже, а походка делается неспешной и плавной. Организм потихоньку приспосабливается к высоте.<br /><br />На следующее утро акклиматизационный выход на скалы Пастухова (4800 метров над уровнем) моря. В подъем идем медленно. Про себя считаю шаги 10...20...100. Сил больше нет. Дышать становится все труднее. Останавливаюсь, тормозя тем самым всю группу. Более сильные уходят вперед. Собираемся вместе уже на скалах. Первый рубеж взят! Спустившись на приют «11» в прямом смысле валимся с ног. А вечером в столовой приюта отмечаем еще одно важное событие. Торт из печенья со сгущенкой, импровизированные свечи... Самому младшему участнику экспедиции Ивану Матасову исполняется 15 лет! Этот свой День рождения Ваня наверняка запомнит на всю жизнь. И неизвестно сколько еще дорог у него впереди, но, судя по всему, путь он выбрал верно...<br /><br />Подготовив необходимое для завтрашнего восхождения снаряжение, спать ложимся рано, но уснуть удается далеко не сразу. В голове рой мыслей, тревоги, опасения, сомнения. Но, тем неменее, в три часа ночи мы покидаем приют, отправляясь к своей мечте...<br /><br />Долго размышляю над последними строками своего репортажа. Как же описать тот отрезок времени - от первого до завершающего шага в 12-часовом подъеме и спуске. Можно просто сказать: «Шли мы, шли и, наконец, пришли...». В принципе-то так оно и было. Но что-то изменилось за это время, что-то стало другим, мы все стали немного другими...<br /><br />Для меня это восхождение было сложным (да и разве бывает легким путь к мечте ;)). Но в этот раз гора нам покорилась, вернее, покорив нас, она позволила побывать у себя в гостях. 11 часов утра 20 августа для всех участников экспедиции станет особой жизненной датой. Я же от всей души благодарю моих спутников: Президента «Компании Белый медведь-97» Сергея Птицына, директора по региональному развитию «Компании Белый медведь-97» Михаила Матасова и его сына Ивана, генерального директора «Компании Белый медведь-97 Красноярск» Александра Камышанского, семью Руновичей, в лице аксакала горного туризма Леонида Дмитриевича и его сыновей Андрея и Александра. Две недели, прожитые с вами в одной команде стали во многих отношениях полезным жизненным уроком. И именно рядом с вами осуществилась моя давняя мечта.<br /><br />Пускай сбываются мечты!!!<br /><br />Татьяна Чернова.</p>'),
                'images' => array(
                    '294_po-doroge-k-gore-schastya.jpg',
                    '295_po-doroge-k-gore-schastya.jpg',
                    '296_po-doroge-k-gore-schastya.jpg',
                ),
                'rewrite' => 'clauses/o-pokhodakh/po-doroge-k-gore-schastya',
            ),
            array(
                'id' => 8,
                'cat_id' => 2,
                'name' => array('В поисках Ковчега Ноева…', 'In search of Noyev\'s Ark …'),
                'anons' => array('<p>Продолжая путешествовать по свету, Максим Богатырев рассказывает нам о своих приключениях.</p>', '<p>Continuing to travel all over the world, Maxim Bogatyrev tells us about the adventures.</p>'),
                'text' => array('<p>Слушая его рассказы мы изучаем мир вместе с ним, тем более что во всех поездках и экспедициях Максима сопровождает снаряжение NOVA TOUR. На этот раз наш путь лежит на легендарную гору Арарат:<br />«Кто бы ни ехал сюда, кто бы ни взбирался на эту гору, у всех возникала мысль об этой библейской притче-легенде-событии. В общем, и мы были не против попробовать поискать Ковчег Ноев. А собрались мы на гору Арарат. Восточная Турция.<br /><br />Все началось очень неожиданно. Да и как написать в рассказе, что что-то ожидалось или планировалось. Будет неинтересно. А так вроде интрига какая то. Мне позвонил Артур Аветисян - мой друг, альпинист и просто отличный человек. И сообщил, что 23 июля его сыну - тоже Артуру, исполняется 11 лет, и он (Артур старший) хочет сделать подарок своему сыну - совершить восхождение на исконно Армянскую гору. Конечно, скажете вы, День рождения достаточно планируемое событие, значит и поездка наша планируемая, но все равно, как-то все быстро произошло и организовалось. Практически от звонка до восхождения - дней 10.<br /><br />Стартовали мы из города Сочи, на пароме. Нигде я не нашел точного описания как добираться таким способом, и в своем роде мы были первопроходцы. Быстроходный катер на подводных крыльях «Гермес» домчал нас до города Трабзон. Турок на границе бодро вклеивал визы в паспорта, даже не заглядывая кому и куда он клеит. Мне кажется, что подсунь ему блокнот или школьную тетрадку - и он с таким же безразличием вклеит туда визу. Лишь бы денег вы ему заплатили. При этом опять же практически в любой валюте. Из Трабзона мы стартовали в город Догубаизит. С приключениями, но добрались.<br /><br />Сочи - паром- город Трабзон и далее город Догубаизит рядом с горой Арарат, рядом с конфликтным узлом четырех стран - Армении, Турции, Ирана и Нагорного Карабаха. Погода не подкачала, видимо собирался второй всемирный потоп и дождик поливал отчаянно и ежедневно. Гора была видна отовсюду. Вершина постоянно была где-то за облаками. Я спросил президента федерации альпинизма Турции, горного гида Сайана, сколько альпинистов взошло на гору в этом сезоне. Он ответил, что пытались многие, а взошло мало. Холодно и ветрено. А у нас веский повод - День рождения. Ну и надежда увидеть Ноев Ковчег, ну и в грязь лицом бы не ударить. А грязи как раз много. Особенно внизу. Жарит, парит турецкое лето. А потом раз и ливень. В Догубаизите к нам присоединились двое москвичей - супруги Колотий.<br /><br />К лагерю 3200 тропа идет по склонам горы, поросшими травой. Много летовок курдов, в которых они живут летом и пасут свой скот - овец, коров и лошадей. Выше 3200 начинается типично вулканический ландшафт - разрушенные лавовые потоки, вулканические бомбы - россыпи выброшенных вулканом камней и выжженные поля туфов. Растительности практически нет - мелкая трава, да цветочки только. Курды взялись организовывать нам какой-то сервис. Но как то все по-курдски у них получилось. Неуклюже малость. Повар потерялся где-то, потом потерялись наши рюкзаки. Слава Богу рюкзаки нашлись. А вот повар так и не нашелся J)<br />В лагере 4200 было много народу. Скопились альпинисты разных стран. Всех их практически сдуло с высоты 4500-4600 при попытке восхождения. Все выходили на гору в 2-3 утра и возвращались из-за непогоды в 5-6. Времени у нас было много, мы уже на второй день достигли второго лагеря на 4200 и поэтому не спешили, думали третий день сходить на 4700 на акклиматизацию. Поэтому встали как-то не особенно рано. А тут гора показалась. Окно погоды. И мы решили попробовать. Вышли наверх в 9.30 утра. С 4600 Дмитрий Колотий и его жена Ольга повернули вниз. Не хватило акклиматизации. А я, Артур старший и именинник Артур младший в 16.30 достигли вершины. Так получилось, что именно в День своего рождения, даже именно в час своего рождения, Артур Аветисян младший стоял на вершине горы Арарат 5135 метров.<br /><br />На другой день - 24 июля, я второй раз взошел на гору с Дмитрием Колотий и болгарским альпинистом Ивлом. Больше никто не рискнул в такую погоду выйти наверх.<br />А потом мы путешествовали по Турции. Побывали на озере Ван и на горячих источниках, на острове Ахтамар и в древней церкви - Ахтамар, которую не разрушили за полторы тысячи лет ее существования. Обратно уплыть на пароме нам не удалось - на море Черном начался затяжной шторм. Поэтому мы перебрались в город Стамбул, а оттуда улетели домой - в Россию.<br /><br />Нашли ли мы Ковчег? Пусть это останется тайной. Но скажу точно – каждый нашел то, что искал...</p>',
                    '<p>Listening to its stories we study the world together with it especially as on all trips and Maxim\'s expeditions accompanies NOVA TOUR equipment. This time our way lies on legendary Mount Ararat:<br />"Whoever went here whoever climbed up this mountain, all had a thought of this bible a parable-legend-event. Generally, and we were not against to try to look for the Ark Noyev. And we gathered for Mount Ararat. East Turkey.</p>
    <p>Everything began very unexpectedly. And how to write in the story that something was expected or planned. It will be uninteresting. And so it seems intrigue any. I was called by Artur Avetisyan - my friend, the climber and simply excellent person. Also I reported that on July 23 to his son - too to Artur, 11 years are executed, and he (Artur Sr.) wants to give a gift to the son - to make an ascension on primordially Armenian mountain. Certainly, you, Birthday will tell rather planned event, the trip our planned, but all the same means also, somehow everything quickly occurred and was organized. Practically from a call to an ascension - days 10.</p>
    <p>We from the city of Sochi, on the ferry started. Anywhere I didn\'t find the exact description how to reach in such a way, and in own way we were pioneers. The high-speed boat on underwater wings "Hermes" brought quickly us to the city of Trabzon. The Turk on border vigorously pasted visas in passports, without looking at all to whom and where he glues. It seems to me that palm off on it a notebook or a school writing-book - and it with the same indifference will paste there the visa. If only money you paid it. Thus besides practically in any currency. From Trabzon we started to the city of Dogubaizit. With adventures, but reached.</p>'),
                'images' => array(
                    '290_v-poiskakh-kovchega-noeva.jpg',
                    '291_v-poiskakh-kovchega-noeva.jpg',
                    '292_v-poiskakh-kovchega-noeva.jpg',
                    '293_v-poiskakh-kovchega-noeva.jpg',
                ),
                'rewrite' => 'clauses/o-pokhodakh/v-poiskakh-kovchega-noeva',
            ),
            array(
                'id' => 16,
                'cat_id' => 3,
                'name' => array('Палатка «Арди 4/5». Инструкция по эксплуатации'),
                'anons' => array('<p>Поздравляем вас с приобретением! При надлежащем уходе данная палатка прослужит вам долго.</p>'),
                'text' => array('<p>Пожалуйста, ознакомьтесь с данной инструкцией, прежде чем устанавливать палатку и сохраните ее для справок в дальнейшем. <br /><br />Удобная палатка «Арди 4/5» идеально подойдет для путешествий. Палатка устанавливается на разборном дуговом каркасе, имеет плотное непромокаемое дно, две внутренние палатки, тамбур и два входа на молнии.<br /><br />Внимание. Комбинируя внутренние отделения можно регулировать число спальных мест. В комплект входят два 2-х местные и одно 3-х местное внутренние отделения.<br /><br /><br /><br />Перед поездкой<br /><br />Прежде чем отправиться в путешествие ознакомьтесь с инструкцией по установки палатки и убедитесь, что все необходимые комплектующие на месте. Вам следует детально ознакомиться с особенностями данной палатки и с условиями и ограничениями использования именно этой модели. Перед каждым походом настоятельно рекомендуем тщательно проверять качество узлов палатки (желательно полностью ее, устанавливая), особенно после долговременного хранения или перед первым использованием.<br /><br /><br /><br />Оптимальное применение<br /><br />Местоположение: Защищенная низина/Долина<br /><br />Погодные условия: Обычные/Умеренные<br /><br />Назначение: Временное жилье<br /><br /><br /><br />Установка<br /><br />При установке данной палатки первым устанавливается наружный тент. Будьте внимательны к дугам. В большинстве случаев поломки дуг происходят на стадии установки или разборки палатки. Перед установкой убедитесь, что у вас достаточно помощников для подстраховки.<br /><br /><br /><br />1. Убедитесь что в месте, где вы хотите установить палатку, нет камней и каких либо других острых предметов. Распакуйте внешний тент и разложите его на земле.<br /><br />2. Соберите дуги. Очень важно, чтобы каждое звено было вставлено в переходник соседнего звена до отказа. В противном случае возможны преждевременные повреждения дуг. <br /><br />3. Для удобства установки, дуги и внешние карманы тента имеют цветовую маркировку. Пропустите дуги в рукава, расположенные на тенте и зафиксируйте их с одной стороны. Вставьте в торцы дуг штыри системы фиксации низа палатки (как показано на схеме) с одной стороны. <br /><br />4. Согните дуги и зафиксируйте их с другой стороны. <br /><br />5. После этого закройте все молнии на наружном тенте, растяните палатку и зафиксируйте нижние края колышками. <br /><br />6. Поднимите дуги. <br /><br />7. Постарайтесь, растянуть палатку, используя все растяжки на наружном тенте. В противном случае возможны повреждения палатки при ее использовании. <br /><br />8. Занесите внутренние палатки под наружный тент и пристегните их к нему изнутри. Начните с дальнего конца и продвигайтесь к выходу. <br /><br />9. После этого зафиксируйте нижние края внутренней палатки колышками, соблюдая равномерность отступов от краев наружного тента.<br />  <br /><br />Разборка палатки<br /><br />Если возможно, разбирайте палатку только после ее полного высыхания. Порядок разборки - противоположный порядку сборки. НЕ пытайтесь ВЫТЯНУТЬ дугу из рукава, ВЫТАЛКИВАЙТЕ ее с противоположного конца. Складывайте палатку в сторону открытого выхода, чтобы дать возможность выхода излишнего воздуха. Если палатка при разборке была влажной, при первой же возможности просушите ее.<br /><br /><br />Пожалуйста, будьте предельно осторожны, если вам приходится разбирать палатку при ветреной погоде. Не пытайтесь сделать это самостоятельно, обязательно попросите кого-нибудь помочь вам. <br /><br /><br />Во время эксплуатации<br /><br /> Оберегайте пленочное покрытие дна и крыши палатки от воздействия абразивных материалов<br /><br /> Палатки, ткань которых содержит синтетические материалы, иногда подвержены конденсату. Не путайте это явление с «протеканием». В большинстве случаев образование конденсата можно избежать, обеспечивая достаточную вентиляцию и оставляя выходы, если это возможно, приоткрытыми.<br /><br /> Не прикасайтесь к внутренней поверхности наружного тента, когда идет дождь.<br /><br /> Не устанавливайте палатку под деревьями. Однако вы можете использовать естественные укрытия при установке, такие как скалы. Выход палатки расположите с подветренной стороны.<br /> НЕ ГОТОВЬТЕ ПИЩУ И НЕ ПОЛЬЗУЙТЕСЬ ОТКРЫТЫМ ОГНЕМ ВНУТРИ ПАЛАТКИ. ВНИМАТЕЛЬНО ПРОЧИТАЙТЕ ПРАВИЛА ПРОТИВОПОЖАРНОЙ БЕЗОПАСНОСТИ ВНУТРИ ПАЛАТКИ.</p>'),
                'rel' => array(13, 14, 15),
                'images' => array(
                    '315_palatka-ardi-45-instruktsi.jpg'
                ),
                'rewrite' => 'clauses/instruktsii/palatka-ardi-45-instruktsiya-po-ekspluatatsii',
            ),
            array(
                'id' => 15,
                'cat_id' => 3,
                'name' => array('Палатка «Арди 3». Инструкция по эксплуатации'),
                'anons' => array('<p>Поздравляем вас с приобретением! При надлежащем уходе данная палатка прослужит вам долго.</p>'),
                'text' => array('<p>Пожалуйста, ознакомьтесь с данной инструкцией, прежде чем устанавливать палатку и сохраните ее для справок в дальнейшем. <br /><br />Удобная палатка «Ardee 3» идеально подойдет для путешествий. Палатка устанавливается на разборном дуговом каркасе, имеет плотное непромокаемое дно, тамбур и один вход на молнии<br /><br /><br />Перед поездкой<br /><br />Прежде чем отправиться в путешествие ознакомьтесь с инструкцией по установки палатки и убедитесь, что все необходимые комплектующие на месте. Вам следует детально ознакомиться с особенностями данной палатки и с условиями и ограничениями использования именно этой модели. Перед каждым походом настоятельно рекомендуем тщательно проверять качество узлов палатки (желательно полностью ее, устанавливая), особенно после долговременного хранения или перед первым использованием.<br /><br /><br />Оптимальное применение<br /><br />Местоположение: Защищенная низина/Долина<br /><br />Погодные условия: Обычные/Умеренные<br /><br />Назначение: Временное жилье<br /><br /><br /><br />Установка<br /><br />При установке данной палатки первым устанавливается наружный тент. Будьте внимательны к дугам. В большинстве случаев поломки дуг происходят на стадии установки или разборки палатки. Перед установкой убедитесь, что у вас достаточно помощников для подстраховки.<br /><br />1. Убедитесь что в месте, где вы хотите установить палатку, нет камней и каких либо других острых предметов.Распакуйте внешний тент и разложите его на земле. 2. Соберите дуги. Очень важно, чтобы каждое звено было вставлено в переходник соседнего звена до отказа. В противном случае возможны преждевременные повреждения дуг.<br /><br />3. Пропустите дуги в рукава, расположенные на тентеи зафиксируйте их с одной стороны. Вставьте в торцы дуг штыри системы фиксации низа палатки (как показано на схеме) с одной стороны. <br /><br />4. Согните дуги и зафиксируйте их с другой стороны. <br /><br />5. После этого закройте все молнии на наружном тенте, растяните палатку и зафиксируйте нижние края колышками. <br /><br />6. Поднимите дуги. <br /><br />7. Постарайтесь растянуть палатку, используя все растяжки на наружном тенте. В противном случае возможны повреждения палатки при ее использовании <br /><br />8. Занесите внутреннюю палатку под наружный тент и пристегните ее к нему внутри. Начните с дальнего конца и продвигайтесь к выходу. <br /><br />9. После этого зафиксируйте нижние края внутренней палатки колышками, соблюдая равномерность отступов от краев наружного тента.<br /> <br /><br />Разборка палатки<br /><br />Если возможно, разбирайте палатку только после ее полного высыхания. Порядок разборки - противоположный порядку сборки. НЕ пытайтесь ВЫТЯНУТЬ дугу из рукава, ВЫТАЛКИВАЙТЕ ее с противоположного конца. Складывайте палатку в сторону открытого выхода, чтобы дать возможность выхода излишнего воздуха. Если палатка при разборке была влажной, при первой же возможности просушите ее.<br /><br /><br />Пожалуйста, будьте предельно осторожны, если вам приходится разбирать палатку при ветреной погоде. Не пытайтесь сделать это самостоятельно, обязательно попросите кого-нибудь помочь вам. <br /><br /><br />Во время эксплуатации<br /><br />Оберегайте пленочное покрытие дна и крыши палатки от воздействия абразивных материалов<br />Палатки, ткань которых содержит синтетические материалы, иногда подвержены конденсату. Не путайте это явление с «протеканием». В большинстве случаев образование конденсата можно избежать, обеспечивая достаточную вентиляцию и оставляя выходы, если это возможно, приоткрытыми.<br />Не прикасайтесь к внутренней поверхности наружного тента, когда идет дождь.<br />Не устанавливайте палатку под деревьями. Однако вы можете использовать естественные укрытия при установке, такие как скалы. Выход палатки расположите с подветренной стороны.<br />НЕ ГОТОВЬТЕ ПИЩУ И НЕ ПОЛЬЗУЙТЕСЬ ОТКРЫТЫМ ОГНЕМ ВНУТРИ ПАЛАТКИ. ВНИМАТЕЛЬНО ПРОЧИТАЙТЕ ПРАВИЛА ПРОТИВОПОЖАРНОЙ БЕЗОПАСНОСТИ ВНУТРИ ПАЛАТКИ.</p>'),
                'rel' => array(13, 14, 15),
                'images' => array(
                    '311_palatka-ardi-3-instruktsiya-.jpg'
                ),
                'rewrite' => 'clauses/instruktsii/palatka-ardi-3-instruktsiya-po-ekspluatatsii',
            ),
            array(
                'id' => 14,
                'cat_id' => 3,
                'name' => array('Палатки «Гори 2, 3, 4» Инструкция по эксплуатации'),
                'anons' => array('<p>Поздравляем вас с приобретением! При надлежащем уходе данная палатка прослужит вам долго.</p>'),
                'text' => array('<p>Пожалуйста, ознакомьтесь с данной инструкцией, прежде чем устанавливать палатку и сохраните ее для справок в дальнейшем. Палатка «Гори» идеально подойдет для путешествий. Палатка устанавливается на разборном дуговом каркасе, имеет плотное непромокаемое дно и два входа на молнии.<br /><br />Перед поездкой<br /><br />Прежде чем отправиться в путешествие ознакомьтесь с инструкцией по установки палатки и убедитесь, что все необходимые комплектующие на месте. Вам следует детально ознакомиться с особенностями данной палатки и с условиями и ограничениями использования именно этой модели. Перед каждым походом настоятельно рекомендуем тщательно проверять качество узлов палатки (желательно полностью ее, устанавливая), особенно после долговременного хранения или перед первым использованием.<br /><br />Оптимальное применение<br /><br />Местоположение: Защищенная низина/Долина<br /><br />Погодные условия: Обычные/Умеренные<br /><br />Назначение: Временное жилье<br /><br />Установка<br /><br />При установке данной палатки первым устанавливается внутренняя палатка. Будьте внимательны к дугам. В большинстве случаев поломки дуг происходят на стадии установки или разборки палатки. Перед установкой убедитесь, что у вас достаточно помощников для подстраховки.<br /><br />1. Убедитесь что в месте, где вы хотите установить палатку, нет камней и каких либо других острых предметов. Распакуйте внутреннюю палатку и разложите его на земле.<br /><br />2. Соберите дуги. Очень важно, чтобы каждое звено было вставлено в переходник соседнего звена до отказа. В противном случае возможны преждевременные повреждения дуг.<br /><br />3. Если есть рукава на внутренней палатке, то пропустите в них дуги, и зафиксируйте их с одной стороны. Вставьте в торцы алюминиевой стойки штырь системы фиксации низа палатки с одной стороны (как показано на схеме) и конец фибергласовой дуги с другой. Дуги должны располагаться крестом.<br /><br />4. Согните дуги и зафиксируйте их с другой стороны. Палатка поднимется, или поднимите дуги.<br /><br />5. Закрепите тент палатки за дуги пластиковыми крючками (если они есть).<br /><br />6. Зафиксируйте по периметру колышками дно палатки.<br /><br />7. Накиньте на палатку тент.<br /><br />8. Вставьте малую дугу в карманы расположенные в верхней части тента. После чего зафиксируйте углы и нижние края тента колышками.<br /><br />9. Постарайтесь, растянуть палатку, используя все растяжки на наружном тенте. В противном случае возможны повреждения палатки при ее использовании.<br />  <br /><br />Разборка палатки<br /><br />Если это возможно, разбирайте палатку только после ее полного высыхания. Порядок разборки - противоположные порядку сборки. НЕ пытайтесь ВЫТЯНУТЬ дугу из рукава, ВЫТАЛКИВАЙТЕ ее с противоположного конца. Складывайте палатку в сторону открытого выхода, чтобы дать возможность выхода излишнего воздуха. Если палатка при разборке была влажной, при первой же возможности просушите ее.<br /><br />Пожалуйста, будьте предельно осторожны, если вам приходится разбирать палатку при ветреной погоде. Не пытайтесь сделать это самостоятельно, обязательно попросите кого-нибудь помочь вам.<br /><br />Во время эксплуатации<br /><br />&bull; Оберегайте пленочное покрытие дна и крыши палатки от воздействия абразивных материалов<br /><br />&bull; Палатки, ткань которых содержит синтетические материалы, иногда подвержены конденсату. Не путайте это явление с «протеканием». В большинстве случаев образование конденсата можно избежать, обеспечивая достаточную вентиляцию и оставляя выходы, если это возможно, приоткрытыми.<br /><br />&bull; Не прикасайтесь к внутренней поверхности наружного тента, когда идет дождь.<br /><br />&bull; Не устанавливайте палатку под деревьями. Однако вы можете использовать естественные укрытия при установке, такие как скалы. Выход палатки расположите с подветренной стороны.<br /><br />&bull; НЕ ГОТОВЬТЕ ПИЩУ И НЕ ПОЛЬЗУЙТЕСЬ ОТКРЫТЫМ ОГНЕМ ВНУТРИ ПАЛАТКИ. ВНИМАТЕЛЬНО ПРОЧИТАЙТЕ ПРАВИЛА ПРОТИВОПОЖАРНОЙ БЕЗОПАСНОСТИ НА ВНУТРИ ПАЛАТКИ.</p>'),
                'rel' => 16,
                'images' => array(
                    '310_palatki-gori-2-3-4-instrukts.jpg'
                ),
                'rewrite' => 'clauses/instruktsii/palatki-gori-2-3-4-instruktsiya-po-ekspluatatsii',
            ),
            array(
                'id' => 13,
                'cat_id' => 3,
                'name' => array('Палатки «Каван 2, 3, 4». Инструкция по эксплуатации', 'Tents "Cavan 2, 3, 4". Maintenance instruction'),
                'anons' => array('<p>Поздравляем вас с приобретением! При надлежащем уходе данная палатка прослужит вам долго.</p>', '<p>We congratulate you on acquisition! At appropriate leaving this tent will serve to you long.</p>'),
                'text' => array('<p>Пожалуйста, ознакомьтесь с данной инструкцией, прежде чем устанавливать палатку и сохраните ее для справок в дальнейшем. Палатка «Каван» идеально подойдет для комфортабельного отдыха или для использования в качестве базовой. Палатка устанавливается на разборном дуговом каркасе, имеет плотное непромокаемое дно, большой тамбур и два входа на молнии.<br /><br />Перед поездкой<br /><br />Прежде чем отправиться в путешествие ознакомьтесь с инструкцией по установки палатки и убедитесь, что все необходимые комплектующие на месте. Вам следует детально ознакомиться с особенностями данной палатки и с условиями и ограничениями использования именно этой модели. Перед каждым походом настоятельно рекомендуем тщательно проверять качество узлов палатки (желательно полностью ее, устанавливая), особенно после долговременного хранения или перед первым использованием.<br /><br />Оптимальное применение<br /><br /> Местоположение: Защищенная низина/Долина<br /> Погодные условия: Обычные/Умеренные<br /> Назначение: Временное жилье<br /><br />Установка<br /><br />При установке данной палатки первым устанавливается внутренняя палатка. Будьте внимательны к дугам. В большинстве случаев поломки дуг происходят на стадии установки или разборки палатки. Перед установкой убедитесь, что у вас достаточно помощников для подстраховки.<br /><br />1. Убедитесь что в месте, где вы хотите установить палатку, нет камней и каких либо других острых предметов. Распакуйте внутреннюю палатку и разложите его на земле.<br /><br />2. Соберите дуги. Очень важно, чтобы каждое звено было вставлено в переходник соседнего звена до отказа. В противном случае возможны преждевременные повреждения дуг.<br /><br />3. Возьмите две самые большие дуги (они одинаковой длины) и вставьте в торцы алюминиевой стойки штырь системы фиксации низа палатки с одной стороны (как показано на схеме) и конец фибергласовой дуги с другой. Дуги должны располагаться крестом.<br /><br />4. Согните дуги и зафиксируйте их с другой стороны. Поднимите дуги.<br /><br />5. Закрепите тент палатки за дуги пластиковыми крючками.<br /><br />6. Зафиксируйте по периметру колышками дно палатки.<br /><br />7. Накиньте на палатку тент.<br /><br />8. Вставьте в переднюю часть тента оставшеюся меньшую из трех дуг и зафиксируйте ее концы в свободных штырях системы фиксации оттяжек палатки.<br /><br />9. После этого закройте все молнии на наружном тенте. Растяните палатку, используя все растяжки на наружном тенте. В противном случае возможны повреждения палатки при ее использовании.<br /><br />10. Зафиксируйте нижние края тента колышками. При необходимости повторно натяните растяжки.</p>
<p>Разборка палатки<br /><br />Если возможно, разбирайте палатку только после ее полного высыхания. Порядок разборки - противоположный порядку сборки. НЕ пытайтесь ВЫТЯНУТЬ дугу из рукава, ВЫТАЛКИВАЙТЕ ее с противоположного конца. Складывайте палатку в сторону открытого выхода, чтобы дать возможность выхода излишнего воздуха. Если палатка при разборке была влажной, при первой же возможности просушите ее.<br /><br /><br />Пожалуйста, будьте предельно осторожны, если вам приходится разбирать палатку при ветреной погоде. Не пытайтесь сделать это самостоятельно, обязательно попросите кого-нибудь помочь вам.<br /><br /><br />Во время эксплуатации<br /><br />&bull; Оберегайте пленочное покрытие дна и крыши палатки от воздействия абразивных материалов<br /><br />&bull; Палатки, ткань которых содержит синтетические материалы, иногда подвержены конденсату. Не путайте это явление с «протеканием». В большинстве случаев образование конденсата можно избежать, обеспечивая достаточную вентиляцию и оставляя выходы, если это возможно, приоткрытыми.<br /><br />&bull; Не прикасайтесь к внутренней поверхности наружного тента, когда идет дождь.<br /><br />&bull; Не устанавливайте палатку под деревьями. Однако вы можете использовать естественные укрытия при установке, такие как скалы. Выход палатки расположите с подветренной стороны.<br /><br />&bull; НЕ ГОТОВЬТЕ ПИЩУ И НЕ ПОЛЬЗУЙТЕСЬ ОТКРЫТЫМ ОГНЕМ ВНУТРИ ПАЛАТКИ. ВНИМАТЕЛЬНО ПРОЧИТАЙТЕ ПРАВИЛА ПРОТИВОПОЖАРНОЙ БЕЗОПАСНОСТИ ВНУТРИ ПАЛАТКИ.</p>',
                    '<p>Please, study this instruction before establishing tent and keep it for references further. The tent "Cavan" will be ideally suited for comfortable rest or for use as the basic. The tent is established on a folding arc framework, has a dense waterproof bottom, the big platform and two entrances on a lightning.</p>
                    <p>Before a trip</p>
                    <p>Before going to travel study the instruction on installations of tent and be convinced that all necessary accessories on a place. You should examine in details features of this tent and conditions and restrictions of use of this model. Before each campaign we recommend strongly to check carefully quality of knots of tent (it is desirable completely it, establishing), especially after long-term storage or before the first use.</p>
                    <p>Optimum application</p>
                    <p>Location: The protected lowland/valley<br /> Weather conditions: Usual/moderate<br /> Appointment: Temporary accommodation</p>
                    <p>Installation</p>
                    <p>At installation of this tent by the first the internal tent is established. Be attentive to arches. In most cases breakages of arches happen at a stage of installation or tent dismantling. Before installation be convinced that you have enough assistants for secure.</p>
                    <p>1 . Be convinced that of a place where you want to establish tent, there are no stones and any other sharp subjects. Unpack internal tent and spread out it on the earth.</p>
                    <p>2 . Collect arches. It is very important that each link was inserted into an adapter of the next link to the full. Otherwise premature damages of arches are possible.</p>
                    <p>3 . Take two biggest arches (they identical length) and insert into end faces of an aluminum rack the probe of system of fixing of a bottom of tent on the one hand (as shown in the scheme) and the end of a fiberglasovy arch with another. Arches have to settle down a cross.</p>
                    <p>4 . Bend arches and record them on the other hand. Lift arches.</p>
                    <p>5 . Fix a tent awning for arches plastic hooks.</p>
                    <p>6 . Record on perimeter pegs a tent bottom.</p>
                    <p>7 . Throw tent with an awning.</p>
                    <p>8 . Insert into forward part of an awning оставшеюся smaller of three arches and record its ends in free probes of system of fixing of delays of tent.</p>
                    <p>9 . After that close all lightnings on an external awning. Stretch tent, using all extensions on an external awning. Otherwise tent damages at its use are possible.</p>
                    <p>10 . Record bottom edges of an awning pegs. If necessary repeatedly pull extensions.</p>'),
                'rel' => 16,
                'images' => array(
                    '306_palatki-kavan-2-3-4-instru.jpg'
                ),
                'rewrite' => 'clauses/instruktsii/palatki-kavan-2-3-4-instruktsiya-po-ekspluatatsii',
            ),
        ),
    );
}